<?php
#-----------------------------------------
#	RT-Theme page_layout_options.php
#
#	Several functions for template builder
#
#-----------------------------------------


class RTThemePageLayoutOptions extends RTThemeAdmin{

	#
	#	Export Templates
	# 
	function rt_export_page_templates( $selectedTemplate = "" ){
		$output = array();

 		//get the saved template names
		$saved_template_names = get_option(RT_THEMESLUG.'_template_names_array');		

		if( is_array( $saved_template_names ) ){
			//create default templates 
			foreach ($saved_template_names as $templateID => $templateData) {


					//check if a template specified
					if ( ! empty( $selectedTemplate ) ) {
						$templateID = $selectedTemplate;
					}

					$this_template = array();

					//the template data
					$this_template["template"] = get_option( RT_THEMESLUG."_".$templateID ); 

					//header output
					$this_template["header_output"] = get_option( RT_THEMESLUG."_".$templateID."_header_output" );							

					//footer output
		 			$this_template["footer_output"] = get_option( RT_THEMESLUG."_".$templateID."_footer_output" ); 
		 
					//content output
		 			$this_template["content_output"] = get_option( RT_THEMESLUG."_".$templateID."_content_output" ); 
		 
					//css output
					$this_template["css_output"] = get_option( RT_THEMESLUG."_".$templateID."_css_output" );
					 
					//template options
					$this_template["template_options"] = get_option( RT_THEMESLUG."_".$templateID."_template_options");

					//add to the output
					array_push( $output, $this_template); 

					//check if a template specified then stop the loop
					if ( ! empty( $selectedTemplate ) ) {
						break;
					}

			}
		}		

		// server time 
		$file_time = date('y-M-d-H-i-s');

		// sent file to user
		header('Content-type: text/plain');  
		header('Content-Disposition: attachment; filename="Templates '.$file_time.'.txt"'); 

		print base64_encode(serialize($output));


		/*	demo image replacement
			$demo_image= "{{demo_image}}"; 
			$output = preg_replace('/https?:\/\/[^ ]+?(?:\.jpg|\.png|\.gif)/', $demo_image, serialize($output));
			$output = preg_replace('!s:(\d+):"(.*?)";!e', "'s:'.strlen('$2').':\"$2\";'", $output );
			print base64_encode($output);	
		*/
	}


	#
	#	Upload demo image
	# 
	function rt_upload_demo_images( $url = "" ){

		$tmp = download_url( $url );

		$file_array= array('name' => "", 'tmp_name' => "" );
		$post_id = 1;
		$desc = "Sample Image";

		if ( is_wp_error( $tmp ) ) { 
			return false;
		}

		// Set variables for storage
		// fix file filename for query strings
		if ( ! is_wp_error( $tmp ) ) {
			preg_match('/[^\?]+\.(jpg|JPG|jpe|JPE|jpeg|JPEG|gif|GIF|png|PNG)/', $url, $matches);
			$file_array['name'] = basename($matches[0]);
			$file_array['tmp_name'] = $tmp;
		}

		// do the validation and storage stuff
		$id = media_handle_sideload( $file_array, $post_id, $desc );

		if ( is_wp_error($id) ) { 
			return false;
		}
		
		return $id;  
	}


	#
	#	Import Templates
	# 
 
	function rt_import_page_templates( $file_content = "" ){
		
		//check file content
		if( empty( $file_content ) ){
			return false;
		}  

		//decode
		$file_content = base64_decode( $file_content );

		//unserialize data and check if an array
		$file_content_array = unserialize( $file_content ); 


		if( ! is_array( $file_content_array ) ){
			return false;								
		}

		//get the saved template names
		$saved_template_names = get_option(RT_THEMESLUG.'_template_names_array');		

		//fix template and row id's
		foreach ( $file_content_array as $key => $template ) {

			$old_templateID = key( $template["template"]->templates );
			$old_templateID_number = explode("_", $old_templateID );
			$old_templateID_number = is_array( $old_templateID_number ) ? $old_templateID_number[1] : "" ; 


			if( ! empty( $old_templateID_number ) ){

				//check the old tempalte ID if exists
				if( isset( $saved_template_names[ $old_templateID] ) ) {
		 			// New Template ID
					$randomnumber = rand(1000, 1000000); 	 
					$file_content = str_replace($old_templateID_number, $randomnumber, $file_content ); 
				}

			}else{
				return false;
			}

		}

		//the demo image
		$demo_image_url = RT_THEMEURI . "/images/sample-image.jpg";

		//try to upload the demo sample image to wp_uploads folder
		if( ! get_option( RT_THEMESLUG."_demo_images_uploaded" ) ){
			
			$demo_image_id = $this->rt_upload_demo_images( $demo_image_url );

			if( $demo_image_id ){
				$demo_image_url = wp_get_attachment_url( $demo_image_id );
			}

			//set a value to prevent multiple uploads even if there is an error with the upload
			update_option( RT_THEMESLUG."_demo_images_uploaded", "true");
		}

		//demo image urls
		$demo_image_replaces = array (
			'{{demo_image}}' => $demo_image_url
		); 
		$file_content = strtr($file_content, $demo_image_replaces);


		//unserialize the fixed one 
		$file_content = preg_replace_callback('/s:(\d+):"(.*?)";/',create_function('$matches','return "s:".strlen($matches[2]).":\"".$matches[2]."\";";'), $file_content );
 
		$file_content_array = unserialize( $file_content ); 

		//new template array
		$newTemplateArray = array();

		//import templates
		foreach ( $file_content_array as $key => $template ) {

			$templateID = key( $template["template"]->templates );  
			$templateName = $template["template"]->templates[ $templateID ]->templateName; 
 
			//the template data
			update_option( RT_THEMESLUG."_".$templateID, rt_stripslashesFull( $template["template"] ) );

			//header output
			update_option( RT_THEMESLUG."_".$templateID."_header_output", stripcslashes( $template["header_output"] ) );							

			//footer output
 			update_option( RT_THEMESLUG."_".$templateID."_footer_output", stripcslashes( $template["footer_output"] ) ); 
 
			//content output
 			update_option( RT_THEMESLUG."_".$templateID."_content_output", stripcslashes( $template["content_output"] ) ); 
 
			//css output
			update_option( RT_THEMESLUG."_".$templateID."_css_output",  $template["css_output"] );
			 
			//template options
			update_option( RT_THEMESLUG."_".$templateID."_template_options", $template["template_options"] );
		
			//new template array
			$newTemplateArray[$templateID] =  array( "name" => $templateName, "is_default_template" => false, "default_template_data" => '' );

		}


		/*
		* update the template list   
		*/

		//update the list
	 	update_option(RT_THEMESLUG.'_template_names_array',  array_merge( $saved_template_names, $newTemplateArray ) );  

		return true;
	}


	#
	#	Fix editor contents
	#	removes the extra html codes of all shortcodes that added into the editor via shortcode helper
	# 
	function fix_editor_contents($content) { 

		// array of custom shortcodes requiring the fix
		$block = join("|",array("rt_column","rt_columns","columns","column","slider","slide","photo_gallery","image","auto_thumb","icon_list","icon_list_line","tabs","tab","accordion","pane","table_column","pricing_table","contact_form","pullquote","banner","button","heading","google_maps","location"));

		// opening tag
		$rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>|<br \/>)(<br \/>)?/","[$2$3]", $content); 
 
		// closing tag
		$rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>|<br \/>)(<br \/>)?/","[/$2]",$rep);  

		return $rep;  			 
	}


	#
	#	Fix editor columns
	#	removes the extra html codes of column shortcodes that added into the editor via shortcode helper
	# 
	function fix_editor_columns( $the_content ){ 
	 
		//clear first part 
		$first='[columns]';
		$second='[column layout='; 
		$content = preg_replace('#('.preg_quote($first).')(.*?)('.preg_quote($second).')#si', '$1$3', $the_content);

		$array = array (
			'<p>[columns]</p>' => '[columns]', 
			'[/columns]</p>' => '[/columns]',  
			'[/column]<br /><br />[/columns]' => '[/column][/columns]',    
			'[/column]<br /><br />[/columns]</p>' => '[/column][/columns]',   
			'[/column]<br /><br /> [column' => '[/column][column',    
			'[/column] <br /><br /> [column layout' => '[/column][column layout',
			'[/column]<br />[/columns]</p>' => '[/column][/columns]',   
			'[/column]<br />[/columns]' => '[/column][/columns]',  	   
			'[/column]'."\n".'<p>&nbsp;</p>'."\n".'[column ' => '[/column][column]',   
		); 

		$content = strtr(trim($content), $array);

		return $content;  
	}


	#
	#	Save Page Templates
	# 
	function rt_save_page_templates(){
		global $wpdb; 

		$savedTemplates       =  $_POST;
		$savedTemplates_Array =  array();  


		//Class For Templates
		$templates  =  new stdClass;

		$box=0;
		$template=0;

		$group_id = "";
		
		foreach($savedTemplates as $key=>$value){
			
			 
			$jump = stristr($key, '_template_name') == TRUE && $value==""  ? true : false ;
			 
			if(!$jump){
				//template name and ID		
				if(stristr($key, '_template_name') == TRUE) {
					
					$template = str_replace('_template_name','',$key); 
					
					$templates->templates[$template] =  new stdClass;

					$templates->templates[$template]->templateID	= $template; 
					$templates->templates[$template]->templateName 	= $value;
 
					//save the templates as an array
					$savedTemplates_Array[$template] = $value; 
				}

				//Page layout - sidebar selection
				if(stristr($key, $templates->templates[$template]->templateID.'_sidebarSelection') == TRUE && $templates->templates[$template]->templateName) { 
					$box++; 
					$templates->templates[$template]->sidebar 		= $value; 
				}	
	
				//group id
				if(stristr($key, 'theGroupID_') == TRUE) {			
					$group_id = $value;  
				}


				//home page boxes
				if(stristr($key, '_home_page_box')                                   == TRUE) {
				$box++;				
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'home_page_box';
				$templates->templates[$template]->contents[$box]->layout             =  $value[0];
				$templates->templates[$template]->contents[$box]->content_id         =  $value[1];
				}
				
				//product list
				if(stristr($key, '_product_box')                                     == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'product_box'; 
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}


				//product carousel
				if(stristr($key, '_product_carousel')                                == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'product_carousel';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}


				if ( class_exists( 'Woocommerce' ) ) {
					//woo product list
					if(stristr($key, '_woo_products_box')                                == TRUE) {
					$box++;
					$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class					
					$templates->templates[$template]->contents[$box]->group_id         	 =  $group_id; // group id
					$templates->templates[$template]->contents[$box]->content_type       =  'woo_products_box'; 
					$templates->templates[$template]->contents[$box]->item_width         =  $value["item_width"]; 
					$templates->templates[$template]->contents[$box]->list_orderby       =  $value["list_orderby"];
					$templates->templates[$template]->contents[$box]->list_order         =  $value["list_order"];
					$templates->templates[$template]->contents[$box]->item_per_page      =  $value["item_per_page"];
					$templates->templates[$template]->contents[$box]->categories         =  isset($value["categories"]) ? $value["categories"] : "";	 
					}
				}
				
				//portfolio list
				if(stristr($key, '_portfolio_box')                                   == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'portfolio_box'; 
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];	
				}

				//portfolio carousel
				if(stristr($key, '_portfolio_carousel')                              == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'portfolio_carousel';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}

				//sidebar boxes
				if(stristr($key, 'sidebar_box')                                      == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'sidebar_box';
				$templates->templates[$template]->contents[$box]->sidebar_id         =  $value["sidebar_id"];
				$templates->templates[$template]->contents[$box]->widget_box_width   =  $value["widget_box_width"]; 
				}
				
				//default content 
				if(stristr($key, 'default_content')                                  == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'default_content';
				$templates->templates[$template]->contents[$box]->layout             =  "one";
				}
				
				//banner box
				if(stristr($key, '_banner_box')                                      == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'banner_box'; 			
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];									 
				}
				
				//Slider box
				if(stristr($key, '_slider_box')                                      == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'slider_box';  
				$templates->templates[$template]->contents[$box]->slider_timeout     =  $value["slider_timeout"];
				$templates->templates[$template]->contents[$box]->slider_height      =  $value["slider_height"];
				$templates->templates[$template]->contents[$box]->slider_width       =  $value["slider_width"];
				$templates->templates[$template]->contents[$box]->image_resize       =  isset($value["image_resize"]) ? $value["image_resize"] : "";  
				$templates->templates[$template]->contents[$box]->image_crop         =  isset($value["image_crop"]) ? $value["image_crop"] : "";  
				$templates->templates[$template]->contents[$box]->flex_slider_effect =  $value["flex_slider_effect"];   
				$templates->templates[$template]->contents[$box]->slides             =  $value["slides"]; 
				}

				//Tabs box
				if(stristr($key, '_tabs_box')                                        == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'tabs_box'; 
 				$templates->templates[$template]->contents[$box]->tabs_style         =  $value["tabs_style"]; 
				$templates->templates[$template]->contents[$box]->tab_contents       =  $value["tab_contents"]; 
				}

				//Accordion box
				if(stristr($key, '_accordion_box')                                   == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'accordion_box'; 
 				$templates->templates[$template]->contents[$box]->accordion_style    =  $value["accordion_style"]; 
 				$templates->templates[$template]->contents[$box]->first_one_open     =  isset($value["first_one_open"]) ? $value["first_one_open"] : "";
				$templates->templates[$template]->contents[$box]->accordion_contents =  $value["accordion_contents"]; 
				}
				
				//Layer Slider box
				if(stristr($key, '_layerslider_box')                                  == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'layerslider_box'; 
				$templates->templates[$template]->contents[$box]->slider_id      	 =  $value["slider_id"];  
				}

				//Revolution Slider box
				if(stristr($key, '_revslider_box')                                  == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'revslider_box'; 
				$templates->templates[$template]->contents[$box]->slider_id      	 =  $value["slider_id"];  
				}

				//google map 
				if(stristr($key, '_google_map')                                      == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'google_map'; 
				$templates->templates[$template]->contents[$box]->module_title       =  $value["module_title"];
				$templates->templates[$template]->contents[$box]->height             =  $value["height"]; 
				$templates->templates[$template]->contents[$box]->zoom               =  $value["zoom"]; 
				$templates->templates[$template]->contents[$box]->list               =  $value["list"]; 			
				}
				
				//contact form
				if(stristr($key, '_contact_form')                                    == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'contact_form'; 
				$templates->templates[$template]->contents[$box]->title              =  $value["title"];
				$templates->templates[$template]->contents[$box]->email              =  $value["email"];
				$templates->templates[$template]->contents[$box]->shortcode          =  $value["shortcode"]; 
				$templates->templates[$template]->contents[$box]->text               =  $value["text"];			
				}
				
				//contact info box
				if(stristr($key, '_icon_list_box')                                == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'icon_list_box'; 
				$templates->templates[$template]->contents[$box]->list     			 =  $value["list"];
				$templates->templates[$template]->contents[$box]->module_title       =  $value["module_title"]; 
				$templates->templates[$template]->contents[$box]->icon_style         =  $value["icon_style"];  
				$templates->templates[$template]->contents[$box]->item_width         =  $value["item_width"];    
				}


				//heading bar
				if(stristr($key, '_heading_bar')                               		 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'heading_bar';
				$templates->templates[$template]->contents[$box]->heading            =  $value["heading"];
				$templates->templates[$template]->contents[$box]->icon               =  $value["icon"]; 
				$templates->templates[$template]->contents[$box]->style              =  $value["style"]; 
				}				

				//space box
				if(stristr($key, '_space_box')                               		 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'space_box';
				$templates->templates[$template]->contents[$box]->height             =  $value["height"];
				}	

				//blog posts
				if(stristr($key, '_blog_box')                                        == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'blog_box';
				$templates->templates[$template]->contents[$box]->layout             =  $value["layout"]; 
				$templates->templates[$template]->contents[$box]->pagination         =  isset($value["pagination"]) ? $value["pagination"] : "";
				$templates->templates[$template]->contents[$box]->list_orderby       =  $value["list_orderby"];
				$templates->templates[$template]->contents[$box]->list_order         =  $value["list_order"];
				$templates->templates[$template]->contents[$box]->item_per_page      =  $value["item_per_page"];
				$templates->templates[$template]->contents[$box]->list_style         =  $value["list_style"];
				$templates->templates[$template]->contents[$box]->list_layout        =  $value["list_layout"];
				$templates->templates[$template]->contents[$box]->categories         =  isset($value["categories"]) ? $value["categories"] : ""; 
				}

				//bog carousel
				if(stristr($key, '_blog_carousel')                                   == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'blog_carousel';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}

				//code box
				if(stristr($key, '_code_box')                                        == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'code_box'; 
				$templates->templates[$template]->contents[$box]->heading            =  $value["heading"];
				$templates->templates[$template]->contents[$box]->code_space         =  $value["code_space"];
				$templates->templates[$template]->contents[$box]->transparent        =  isset($value["transparent"]) ? $value["transparent"] : "";
				$templates->templates[$template]->contents[$box]->no_padding         =  isset($value["no_padding"]) ? $value["no_padding"] : ""; 						
				}


				//grid
				if(stristr($key, '_grid')												 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box]                         = new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id               = $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type           = 'grid';
				$templates->templates[$template]->contents[$box]->part                   = $value["grid"];   
				$templates->templates[$template]->contents[$box]->header_purpose         = $value["header_purpose"]; 
				$templates->templates[$template]->contents[$box]->footer_purpose         = $value["footer_purpose"];   
				$templates->templates[$template]->contents[$box]->newtemplate            = isset($value["newtemplate"]) ? $value["newtemplate"] : ""; 					
				$templates->templates[$template]->contents[$box]->breadcrumb             = isset($value["breadcrumb"]) ? $value["breadcrumb"] : ""; 	
				$templates->templates[$template]->contents[$box]->breadcrumb_position    = isset($value["breadcrumb_position"]) ? $value["breadcrumb_position"] : ""; 	  
				$templates->templates[$template]->contents[$box]->page_title             = isset($value["page_title"]) ? $value["page_title"] : ""; 	  
				$templates->templates[$template]->contents[$box]->display_widgets        = isset($value["display_widgets"]) ? $value["display_widgets"] : ""; 	  
				$templates->templates[$template]->contents[$box]->header_options         = isset($value["header_options"]) ? $value["header_options"] : ""; 					
				$templates->templates[$template]->contents[$box]->sidebar_selection      = isset($value["sidebar_selection"]) ? $value["sidebar_selection"] : ""; 					
				$templates->templates[$template]->contents[$box]->sidebar_id             = isset($value["sidebar_id"]) ? $value["sidebar_id"] : ""; 					
				$templates->templates[$template]->contents[$box]->first_top_widget_name  = isset($value["first_top_widget_name"]) ? $value["first_top_widget_name"] : ""; 					
				$templates->templates[$template]->contents[$box]->second_top_widget_name = isset($value["second_top_widget_name"]) ? $value["second_top_widget_name"] : ""; 
				$templates->templates[$template]->contents[$box]->background_options     = isset($value["background_options"]) ? $value["background_options"] : ""; 
				$templates->templates[$template]->contents[$box]->color_set              = isset($value["color_set"]) ? $value["color_set"] : ""; 
				$templates->templates[$template]->contents[$box]->column_options         = isset($value["column_options"]) ? $value["column_options"] : ""; 
				$templates->templates[$template]->contents[$box]->row_style_options      = isset($value["row_style_options"]) ? $value["row_style_options"] : ""; 

				}

				//columns
				if(stristr($key, '_column')                                        	 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'column';
				$templates->templates[$template]->contents[$box]->layout      		 =  isset($value["layout"]) ? $value["layout"] : ""; 
				$templates->templates[$template]->contents[$box]->part               =  isset($value["column"]) ? $value["column"] : "";  
				}


				//New Content Boxex 
				if(stristr($key, '_new_content_box')                                      == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box]                          = new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id                = $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type            = 'new_content_box'; 			
				$templates->templates[$template]->contents[$box]->title                   = $value["title"];
				$templates->templates[$template]->contents[$box]->title_position          = $value["title_position"];
				$templates->templates[$template]->contents[$box]->text                    = $value["text"];
				$templates->templates[$template]->contents[$box]->featured_image          = $value["featured_image"]; 
				$templates->templates[$template]->contents[$box]->icon                    = $value["icon"]; 
				$templates->templates[$template]->contents[$box]->icon_style              = $value["icon_style"]; 
				$templates->templates[$template]->contents[$box]->text_position           = $value["text_position"];
				$templates->templates[$template]->contents[$box]->link                    = $value["link"];
				$templates->templates[$template]->contents[$box]->link_text               = $value["link_text"];
				$templates->templates[$template]->contents[$box]->link_target             = $value["link_target"]; 									  
				$templates->templates[$template]->contents[$box]->image_style             = $value["image_style"];
				}

				//New Content Boxex 
				if(stristr($key, '_content_icon_box')                                     == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box]                          = new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id                = $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type            = 'content_icon_box'; 			
				$templates->templates[$template]->contents[$box]->title                   = $value["title"];
				$templates->templates[$template]->contents[$box]->title_position          = $value["title_position"];
				$templates->templates[$template]->contents[$box]->text                    = $value["text"]; 
				$templates->templates[$template]->contents[$box]->icon                    = $value["icon"]; 
				$templates->templates[$template]->contents[$box]->icon_style              = $value["icon_style"]; 
				$templates->templates[$template]->contents[$box]->text_position           = $value["text_position"];
				$templates->templates[$template]->contents[$box]->link                    = $value["link"];
				$templates->templates[$template]->contents[$box]->link_text               = $value["link_text"];
				$templates->templates[$template]->contents[$box]->link_target             = $value["link_target"]; 									  
				}


				//New Content Boxex 
				if(stristr($key, '_text_box')                                             == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box]                          = new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id                = $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type            = 'text_box';
				$templates->templates[$template]->contents[$box]->values                  = $value["values"];
				}

				//horizontal line
				if(stristr($key, '_horizontal_line')                                 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box]                     =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'horizontal_line';
				$templates->templates[$template]->contents[$box]->style              =  $value["style"];   
				$templates->templates[$template]->contents[$box]->margin_top         =  $value["margin_top"];     
				$templates->templates[$template]->contents[$box]->margin_bottom      =  $value["margin_bottom"];     
				}


				//Staff 
				if(stristr($key, '_staff_box')  			                         == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'staff_box';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}

				//Testimonails
				if(stristr($key, '_testimonial_box')  			                     == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'testimonial_box';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}

				//Testimonail Carousel
				if(stristr($key, '_testimonial_carousel') 			                 == TRUE) {
				$box++;
				$templates->templates[$template]->contents[$box] 					 =  new stdClass; //create new sub class				
				$templates->templates[$template]->contents[$box]->group_id           =  $group_id; // group id
				$templates->templates[$template]->contents[$box]->content_type       =  'testimonial_carousel';
				$templates->templates[$template]->contents[$box]->values             =  $value["values"];
				}

				//line up boxes
				if(stristr($key, $templates->templates[$template]->templateID.'_line_up_boxes') == TRUE && $templates->templates[$template]->templateName) {
					$box++;
					$templates->templates[$template]->lineup 						=  $value; 
				} 
			} 

		}


		//save the object	 
		update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID, $templates);


		//save the tempalte output as shortocde	 
		$get_outputs = $this->generate_template_output($templates->templates[$template]->contents,$templates->templates[$template]->templateID);

		//save template parts
		if( is_array( $get_outputs ) ){

			//save header outptt
			if( ! empty( $get_outputs["header"] )){
				update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID."_header_output", $get_outputs["header"]);							
			}

			//save footer outptt
			if( ! empty( $get_outputs["footer"] )){
				update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID."_footer_output", $get_outputs["footer"]);							
			}

			//save content outptt
			if( ! empty( $get_outputs["content"] )){
				update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID."_content_output", $get_outputs["content"]);							
			}

			//save css outptt
			if( ! empty( $get_outputs["css"] )){
				update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID."_css_output", $get_outputs["css"]);
			}

			//save template options
			if( ! empty( $get_outputs["template_options"] )){
				update_option( RT_THEMESLUG."_".$templates->templates[$template]->templateID."_template_options", $get_outputs["template_options"]);
			}			
		}
 
		//get the saved template names
		$saved_template_names = is_array( get_option(RT_THEMESLUG.'_template_names_array') ) ? get_option(RT_THEMESLUG.'_template_names_array') : array() ;


		//add the new template name to the list 

		if( ! isset( $saved_template_names[ $templates->templates[$template]->templateID ] ) ){

			//new template values
			$newTemplateId = $templates->templates[$template]->templateID;
			$newTemplateName = $templates->templates[$template]->templateName;

			//new template array
			$newTemplateArray  = array(
									$newTemplateId => array(
										"name" => $newTemplateName,
										"is_default_template" => false,
										"default_template_data" => ''
									)
								); 

			//update the list
			update_option(RT_THEMESLUG.'_template_names_array',  array_merge( $saved_template_names, $newTemplateArray ) ); 
		}else{

			$saved_template_names[ $templates->templates[$template]->templateID ]["name"] = $templates->templates[$template]->templateName;

			update_option(RT_THEMESLUG.'_template_names_array',  $saved_template_names ); 

		}
	}


	#
	#	Generate Template Output
	# 
	function generate_template_output($template_contents = "", $templateID = ""){
		global $rt_google_fonts; 

		// output
		$template_output = "";		
		$header_output = "";		
		$footer_output = "";	
		$footer_started = false;
		$css_output = array("color_sets"=>array(),"backgrounds"=>array(),"css_codes"=>"","fonts"=>array());		

		//template options
		$template_options = array();

		//variables
		$start_row = $next_item_width = $count_item_widths = $columns_started = "";
		$layout_width_values = array("four-five"=>48,"three-four"=>45,"two-three"=>40,"five"=>12,"four"=>15,"three"=>20,"two"=>30,"one"=>60);
		$column_class_names	 = array( 2=>"four-five", 3=>"three-four", 4=>"two-three", 8=>"five", 7=>"four", 6=>"three", 5=>"two", 1=>"one" );
		$row_counter = 1;
		$header_purpose = isset( $header_purpose ) && ! empty( $header_purpose ) ? $header_purpose : false;
		$footer_purpose = isset( $footer_purpose ) && ! empty( $footer_purpose ) ? $footer_purpose : false;

		// Create contents
		foreach($template_contents as $item_num => $template){ 

			//extract template vars
			extract( get_object_vars( $template ) ) ;

			//content type
			$content_type = isset( $content_type ) ? $content_type : "";


			//columns holder for other elemets
			if ( ! $header_purpose && empty( $columns_started ) && $content_type != "column" && $content_type != "grid" && $content_type != "slider_box" && $content_type != "space_box" ){
				$template_output .= '[rt_columns]';
			}

			//colorsets and bacgrounds
			if( $content_type == "grid" && $part == "first"){	 				 					

 					// container
					if( $header_purpose ){
						$container = "body .header-".str_replace("templateid_", "", $templateID);
					}elseif ( $footer_purpose ) {
						$container = "body #container .footer-".str_replace("templateid_", "", $templateID);
					}else{
						$container = '#row-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
					}

					// colorset
					$colorset_array = array("container" => $container, "selection" => $color_set["color_set_selection"], "values" => array() );

					if( $color_set["color_set_selection"] == "new"){
						$colorset_array["values"] = array(
							"primary" => $color_set["primary"],// primary color
							"font" => $color_set["font"],// font color
							"light_font" => $color_set["light_font"],// light font color
							"headings" => $color_set["headings"],// heading color 
							"heading_links" => $color_set["heading_links"],// heading :hover color
							"link" => $color_set["link"],// link color
							"link_hover" => $color_set["link_hover"],// link :hover color
							"highlighted" => $color_set["highlighted"],// highlighted content background color 
							"border" => $color_set["border"],// border color 
							"social_media" => $color_set["social_media"],// social media base color  
						);   
					}

					array_push($css_output["color_sets"], $colorset_array );
					

					// background
					$background_array = array("container" => $container, "selection" => $background_options["background_selection"], "values" => array() );

					if( $background_options["background_selection"] == "new"){
						$background_array["values"] = array(
							"background_color" => isset( $background_options["background_color"] ) ? $background_options["background_color"] : "",// content background color		
							"background_image_url" => isset( $background_options["background_image_url"] ) ? $background_options["background_image_url"] : "", //background-image 
							"background_attachment" => isset( $background_options["background_attachment"] ) ? $background_options["background_attachment"] : "", //background-attachment
							"background_position" => isset( $background_options["background_position"] ) ? $background_options["background_position"] : "", //background-position
							"background_repeat" => isset( $background_options["background_repeat"] ) ? $background_options["background_repeat"] : "", //background-repeat
							"background_size" => isset( $background_options["background_size"] ) ? $background_options["background_size"] : "", //background-size
						);
 
					} 

					array_push($css_output["backgrounds"], $background_array );
 					
			}
		 
			//header
			if( $content_type == "grid" && $header_purpose ){	


				if ( $part == "first" ){ //first part
					$template_output .= '[header selector_class="header-'.str_replace("templateid_", "", $templateID).'" header_options="'.$header_options.'" breadcrumb="'.$breadcrumb.'" page_title="'.$page_title.'" breadcrumb_position="'.$breadcrumb_position.'"]';
 
				 	//keep common values  
			 		$breadcrumb_position_keep = $breadcrumb_position;
			 		$page_title_keep = $page_title;
			 		$breadcrumb_keep = $breadcrumb;


			 		//add values to $template_options
					$template_options = array( 
						"breadcrumb_position" => $breadcrumb_position, 
						"display_title" => $page_title, 
						"display_breadcrumb" => $breadcrumb, 
						"header_background_options" => $header_options,
						"first_top_widget_name" => $first_top_widget_name,
						"second_top_widget_name" => $second_top_widget_name
					);

				}

				if ( $part == "second" ){ //second part
					$template_output .= "[/header]";

					$header_output = $template_output;
					$template_output  = "";													

				}		
				
			}

			//footer
			elseif( $content_type == "grid" && $footer_purpose ){	


				if ( $part == "first" ){ //first part
					$save_template_output = $template_output;
					$template_output  = "";
					$template_output .= '[footer selector_class="footer-'.str_replace("templateid_", "", $templateID).'"]';  						  					

			 		//add values to $template_options
					$template_options["display_widgets"] = $display_widgets;

					$footer_started = true;
				}

				if ( $part == "second" ){ //second part
					$template_output .= "[/footer]";
					$footer_output = $template_output;

					$template_output  = $save_template_output;													

				}		
				
			}			

			//rows
			elseif( $content_type == "grid" && ! $header_purpose && ! $footer_purpose ){
				if ( $part == "first" ){ //first part

					$row_id = 'row-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';


					//get row style  
					$row_class  = "";
					$row_class .= $background_options["background_selection"] == "ca2" ? "row-style-2" : "";
					$row_class .= $background_options["background_selection"] == "ca3" ? "row-style-3" : "";
					
					//get row width
					$full_width_row = $row_style_options["row_width"] == "full" ? "true": "";

					//columns css
					$row_paddings = "";
					$row_paddings .= ! empty( $row_style_options["padding_top"] )  ?  sprintf('#%1$s { padding-top: %2$spx; }', $row_id."", $row_style_options["padding_top"] ) : "";
					$row_paddings .= ! empty( $row_style_options["padding_left"] ) ?  sprintf('#%1$s { padding-left: %2$spx; }', $row_id."", $row_style_options["padding_left"] ) : "";
					$row_paddings .= ! empty( $row_style_options["padding_right"] ) ?  sprintf('#%1$s { padding-right: %2$spx; }', $row_id."", $row_style_options["padding_right"] ): "";
					$row_paddings .= ! empty( $row_style_options["padding_bottom"] ) ? sprintf('#%1$s { padding-bottom: %2$spx; }', $row_id."", $row_style_options["padding_bottom"] ): ""; 
					$row_paddings = ! empty( $row_paddings ) ? sprintf('%s', $row_paddings ) . '' . sprintf('@media only screen and (max-width: 767px) { #%1$s { padding-left: 0px; padding-right: 0px; } }', $row_id ) : "";

					//columns css
					$column_paddings = "";
					$column_paddings .= ! empty( $column_options["padding_top"] ) ?  sprintf('#%1$s >  .row  > .box { padding-top: %2$spx; }', $row_id."-content", $column_options["padding_top"] ) : "";
					$column_paddings .= ! empty( $column_options["padding_left"] ) ?  sprintf('#%1$s >  .row  > .box { padding-left: %2$spx; }', $row_id."-content", $column_options["padding_left"] ) : "";
					$column_paddings .= ! empty( $column_options["padding_right"] ) ?  sprintf('#%1$s >  .row  > .box { padding-right: %2$spx; }', $row_id."-content", $column_options["padding_right"] ): "";
					$column_paddings .= ! empty( $column_options["padding_bottom"] ) ? sprintf('#%1$s >  .row  > .box { padding-bottom: %2$spx; }', $row_id."-content", $column_options["padding_bottom"] ): "";
					$column_paddings .= ! empty( $column_paddings ) ? sprintf('@media only screen and (max-width: 767px) {  #%1$s >  .row  > .box { padding-left: 5px;padding-right: 5px; }}', $row_id."-content") : "";
					
					$paddings = ! empty( $column_paddings ) ? "true" : "";

					$css_output["css_codes"] .= $row_paddings;
					$css_output["css_codes"] .= $column_paddings;
					$css_output["css_codes"] .= $column_options["background_selection"] == "new"  ? sprintf('#%1$s >  .row  > .box { background-color: %2$s; }', $row_id."-content", $column_options["background_color"] ): "";
					$css_output["css_codes"] .= $column_options["background_selection"] == "half_transparent"  ? sprintf('#%1$s >  .row  > .box { background-image: url(%2$s/images/transparent-white.png); }', $row_id."-content", RT_THEMEURI ): "";

					$sidebar_id = is_array( $sidebar_id ) ? implode(",", $sidebar_id ) : "";
					$template_output .= '[row full_width_row="'.$full_width_row.'" row_counter='.$row_counter.' page_title="'.$page_title_keep.'" breadcrumb="'.$breadcrumb_keep.'" breadcrumb_position="'.$breadcrumb_position_keep.'" id="'.$row_id.'" sidebar_selection = "'.$sidebar_selection .'" sidebar_id = "'. $sidebar_id .'" paddings = "'. $paddings .'" class="'. $row_class .'"]';

					$sidebar_id = $sidebar_selection = $column_paddings = "";

				 	//the row counter
				 	$row_counter++;
				}

				if ( $part == "second" ){ //second part
					$template_output .= "[/row]";
				}		
			}

			//columns
			elseif( $content_type == "column" ){ 
		 
		 		$count_column_widths = isset( $count_column_widths ) ? $count_column_widths : 0;


				if ( $part == "first" ){ //first part

					//create column holder
					$template_output .= ($count_column_widths == 0 || $count_column_widths == "") ? '[rt_columns]' : "";
						
					//start counter for column holder
			 		$this_column_width =  $layout_width_values[$column_class_names[$layout]];  // finds width of this item as in $layout_width_values		
			 		$count_column_widths = $count_column_widths + $this_column_width;

			 		//start column
					$template_output .= '[rt_column layout="'.$column_class_names[$layout].'"]';

					$columns_started = true;
				}

				if ( $part == "second" ){ //second part

					//end column
					$template_output .= "[/rt_column]";


					//find the next columns width 
					if( isset($template_contents[$item_num+1]->content_type) && $template_contents[$item_num+1]->content_type == "column" ){			
						$next_column_width = $layout_width_values[$column_class_names[$template_contents[$item_num+1]->layout]] ; 
					}else{
						$next_column_width = 60; // there is no next column so this must be hightest value
					}	

					//close the column holder
					if ( $count_column_widths + $next_column_width  > 60 ){
						$template_output .= '[/rt_columns]';
						$count_column_widths = 0; // reset the column counter
						$columns_started = "";
					}	

				}		
		  
			}

			//content boxes - with featured image
			elseif( $content_type == "new_content_box" ){

				$content_box_id = 'content-box-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

				$template_output .= '[content_box id="'.$content_box_id.'" title="'.htmlspecialchars( $title ).'" title_position="'.$title_position.'" featured_image="'.$featured_image.'" image_style="'.$image_style.'" icon="'.$icon.'" icon_style="'.$icon_style.'" text_position="'.$text_position.'" link="'.htmlspecialchars($link).'" link_text="'.htmlspecialchars($link_text).'" link_target="'.htmlspecialchars($link_target).'"]';

 				//fix editor shortcodes
 				$text = $this->fix_editor_columns($text);
				$text = $this->fix_editor_contents($text);
								
				$template_output .= $text;
				$template_output .= '[/content_box]'; 

			}

			//content boxes - with icon
			elseif( $content_type == "content_icon_box" ){

				$content_box_id = 'content-box-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
			 
				$template_output .= '[content_icon_box id="'.$content_box_id.'" title="'.htmlspecialchars( $title ).'" title_position="'.$title_position.'" icon="'.$icon.'" icon_style="'.$icon_style.'" text_position="'.$text_position.'" link="'.htmlspecialchars($link).'" link_text="'.htmlspecialchars($link_text).'" link_target="'.htmlspecialchars($link_target).'"]';

 				//fix editor shortcodes
 				$text = $this->fix_editor_columns($text);
				$text = $this->fix_editor_contents($text);

				$template_output .= $text;
				$template_output .= '[/content_icon_box]'; 

			}

			//text boxes
			elseif( $content_type == "text_box" ){
			 	
			 	$text = $font_size = $font_color = $heading_color = $font_family_text = $font_family_heading = $font_family_heading_css = $font_family_text_css = "";
			 	extract( $values );

				$text_box_id = 'text-box-'.str_replace("templateid_", "", $templateID).'-'.$group_id.''; 
				

				//font family heading
				if( ! empty( $font_family_text ) ){
					$font_family_text = stripslashes( $font_family_text );
					if( isset($rt_google_fonts[$font_family_text] ) ){ //check if it is a google font
						$font_family_text_css = "'".$rt_google_fonts[$font_family_text][0]."',sans-serif" ; 
						$font_weight_text_css = isset( $rt_google_fonts[$font_family_text][2] ) ? $rt_google_fonts[$font_family_text][2]: "normal";
					}else{
						$font_family_text_css = $font_family_text;
						$font_weight_text_css ="normal";
					}
				} 

				//font family heading
				if( ! empty( $font_family_heading ) ){
					$font_family_heading = stripslashes( $font_family_heading );

					if( isset($rt_google_fonts[$font_family_heading] ) ){ //check if it is a google font
						$font_family_heading_css = "'".$rt_google_fonts[$font_family_heading][0]."',sans-serif" ; 
						$font_weight_heading_css = isset( $rt_google_fonts[$font_family_heading][2] ) ? $rt_google_fonts[$font_family_heading][2]: "normal";
					}else{
						$font_family_heading_css = $font_family_heading;
						$font_weight_heading_css ="normal";
					}
				}

				$heading_selector = sprintf('#%1$s h1,#%1$s h2,#%1$s h3,#%1$s h4,#%1$s h5,#%1$s h6',$text_box_id);

			 	$css_output["css_codes"] .= ! empty( $font_color ) ? sprintf('#%1$s p{color:%2$s}', $text_box_id, $font_color ) : "";
			 	$css_output["css_codes"] .= ! empty( $font_size ) ? sprintf('#%1$s p{font-size:%2$spx;line-height:150%%;}', $text_box_id, $font_size ) : "";
				$css_output["css_codes"] .= ! empty( $heading_color ) ? sprintf('%1$s{color:%2$s;}', $heading_selector, $heading_color ) : ""; 				
				$css_output["css_codes"] .= ! empty( $font_family_text_css ) ? '#'. $text_box_id .' p{font-family:'. $font_family_text_css .'; font-weight:'.$font_weight_text_css.' !important;}' : ""; 				
				$css_output["css_codes"] .= ! empty( $font_family_heading_css ) ? $heading_selector .'{font-family:'. $font_family_heading_css .'; font-weight:'.$font_weight_heading_css.' !important;}' : "";


				/*
				add the selected fonts to the fonts array of this template to 
				be loaded with wp_enqueue in custom_styling.php
				*/
				if( ! empty( $font_family_text ) ){					
					array_push($css_output["fonts"], $font_family_text );
				}

				if( ! empty( $font_family_heading ) ){
					array_push($css_output["fonts"], $font_family_heading );
				}
 				
 				//fix editor shortcodes
 				$text = $this->fix_editor_columns($text);
				$text = $this->fix_editor_contents($text);

				$template_output .= '[text_box id="'.$text_box_id.'"]';  
				$template_output .= $text; 
				$template_output .= '[/text_box]'; 

			}

			//slider
			elseif( $content_type == "slider_box" ){			 

			 	/*
			 	//[slider slider_width="650" slider_height="300" slider_script=""]
			 		[slide link="link" title="title" img_url="" video_url="" styling="" title_color="" title_bg_color="" text_color="" text_bg_color="" title_size="" text_size=""]slide_text[/slide] 
				[/slider]
			 	*/

			 	
			 	$slides_output = "";

			 	foreach ($slides["slide_hidden_value"] as $key => $options) {
			 		if( ! empty( $slides["slide_hidden_value"][$key] ) ){
				 		$slide_title = $slide_text = $slide_image_url = $slide_link = $text_size = $title_size = $text_bg_color = $title_bg_color = $title_color = $styling = "";

						$slide_title = ! empty( $slides["slide_title"][$key] ) ? $slides["slide_title"][$key] : "";
						$slide_text  = ! empty( $slides["slide_text"][$key] ) ? $slides["slide_text"][$key] : "";		
						$slide_image_url = ! empty( $slides["slide_image_url"][$key] ) ? $slides["slide_image_url"][$key] : "";	
						$slide_link  = ! empty( $slides["slide_link"][$key] ) ? $slides["slide_link"][$key] : "";	 				 	
						$text_align = ! empty( $slides["text_align"][$key] ) ? $slides["text_align"][$key] : "";					 	
						$stretch_images = ! empty( $slides["stretch_images"][$key] ) ? $slides["stretch_images"][$key] : "";	 
						$styling     = ! empty( $slides["styling"][$key] ) ? $slides["styling"][$key] : "";
						$title_color     = ! empty( $slides["title_color"][$key] ) ? $slides["title_color"][$key] : "";
						$title_bg_color     = ! empty( $slides["title_bg_color"][$key] ) ? $slides["title_bg_color"][$key] : "";
						$text_color     = ! empty( $slides["text_color"][$key] ) ? $slides["text_color"][$key] : "";
						$text_bg_color     = ! empty( $slides["text_bg_color"][$key] ) ? $slides["text_bg_color"][$key] : "";
						$title_size     = ! empty( $slides["title_size"][$key] ) ? $slides["title_size"][$key] : "";
						$text_size     = ! empty( $slides["text_size"][$key] ) ? $slides["text_size"][$key] : ""; 

						if( $slide_title || $slide_text || $slide_image_url ){
							$slides_output .= sprintf('[slide link="%s" title="%s" img_url="%s" text_align="%s" stretch_images="%s" styling="%s" title_color="%s" title_bg_color="%s" text_color="%s" text_bg_color="%s" title_size="%s" text_size="%s"]%s[/slide]',$slide_link, $slide_title, $slide_image_url, $text_align, $stretch_images, $styling, $title_color, $title_bg_color, $text_color, $text_bg_color, $title_size, $text_size, $slide_text);			 			
						}					 		
			 		}

			 	}		

				$template_output .= sprintf('[slider slider_width="%s" slider_height="%s" slider_script="%s" image_resize="%s" image_crop="%s" slider_timeout="%s" flex_slider_effect="%s"]%s[/slider]', $slider_width, $slider_height, "flex_slider", $image_resize, $image_crop, $slider_timeout, $flex_slider_effect, $slides_output );

			}

			//tabs
			elseif( $content_type == "tabs_box" ){
			 
			 	/*
			 	//[tabs tab1="" tab1-icon="" tab2="" tab2-icon="" tab3="" tab3-icon=""][/tabs]
			 		[tab][/tab]
			 	[/tabs]
			 	*/
		 
			 	$tab_captions_output = '[tabs tabs_style="'.$tabs_style.'" ' ;
			 	$tab_contents_output = "";

			 	$tab_count = 1;

			 	foreach ($tab_contents["caption"] as $key => $options) {


			 		$tab_caption = $tab_text = $tab_icon = "";
					$tab_caption = ! empty( $tab_contents["caption"][$key] ) ? $tab_contents["caption"][$key] : "";
					$tab_text    = ! empty( $tab_contents["text"][$key] ) ? $tab_contents["text"][$key] : "";		
					$tab_icon    = ! empty( $tab_contents["icon"][$key] ) ? $tab_contents["icon"][$key] : "";	
				 	
				 	$tab_captions_output .= ! empty( $tab_caption ) ? 'tab'.$tab_count.'="'.htmlspecialchars($tab_caption).'" ' : "";
				 	$tab_captions_output .= ! empty( $tab_icon ) ? 'tab'.$tab_count.'_icon="'.$tab_icon.'" ' : "";
				 	$tab_contents_output .= ! empty( $tab_caption ) ? '[tab]'.$tab_text.'[/tab]' : "";

				 	$tab_count++;
			 	}
			
				$tab_captions_output .= "]";	 	

				$template_output .= $tab_captions_output ." " . stripslashes( $tab_contents_output );

				$template_output .= '[/tabs]'; 

			}

			//accordions
			elseif( $content_type == "accordion_box" ){
			 
			 	/*
			 	//[accordion align="" style=""]
			 		[pane title="" icon=""][/pane]
			 	[/accordion]
			 	*/

			 	$first_one_open = isset( $first_one_open ) && !empty( $first_one_open ) ? "true" : "";	

			 	$accordion_contents_output = '';

			 	foreach ($accordion_contents["caption"] as $key => $options) {

			 		$accordion_caption = $accordion_text = $accordion_icon = "";
					$accordion_caption = ! empty( $accordion_contents["caption"][$key] ) ? $accordion_contents["caption"][$key] : "";
					$accordion_text    = ! empty( $accordion_contents["text"][$key] ) ? $accordion_contents["text"][$key] : "";		
					$accordion_icon    = ! empty( $accordion_contents["icon"][$key] ) ? $accordion_contents["icon"][$key] : "";	  
				 	 
					$accordion_contents_output .= ! empty( $accordion_caption ) ? '[pane title="'.htmlspecialchars($accordion_caption).'" ' : "";
				 	$accordion_contents_output .= ! empty( $accordion_caption ) && ! empty( $accordion_icon ) ? 'icon="'.$accordion_icon.'" ' : "";
				 	$accordion_contents_output .= ! empty( $accordion_caption ) ? ']'.$accordion_text.'[/pane]' : "";

			 	}

				$template_output .= ! empty( $accordion_contents_output ) ? sprintf('[accordion style="%s" first_one_open="%s"]%s[/accordion]',$accordion_style, $first_one_open, stripslashes( $accordion_contents_output ) ) : ""; 

				$first_one_open = "";
			}	


			//icon lists
			elseif( $content_type == "icon_list_box" ){
			 
			 	/*
			 	//[icon_list title=""]
			 		[icon_list_line icon=""]content[/icon_list_line]
			 	[/icon_list]
			 	*/

			 	$icon_list_output = '';

			 	foreach ($list["text"] as $key => $options) {

					$list_text  = ! empty( $list["text"][$key] ) ? $list["text"][$key] : "";	
					$list_icon  = ! empty( $list["icon"][$key] ) ? $list["icon"][$key] : "";

		 		 	if( !empty( $list_text ) ){
						$icon_list_output .= '[icon_list_line icon="'.$list_icon.'"]'.$list_text.'[/icon_list_line]';
		 		 	} 

			 	}

				$template_output .= ! empty( $icon_list_output ) ? sprintf('[icon_list title="%s" icon_style="%s" item_width="%s"]%s[/icon_list]',$module_title,$icon_style,$item_width,$icon_list_output ) : ""; 

			}	

			//blog box
			elseif( $content_type == "blog_box" ){
			 
			 	/*
			 	//[blog_box pagination="" list_orderby="" list_order="" item_per_page="" list_style="" list_layout="" categories="" ]
			 	*/

			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : "";

 				$template_output .=  sprintf('[blog_box pagination="%s" list_orderby="%s" list_order="%s" item_per_page="%s" list_style="%s" list_layout="%s" categories="%s"]',$pagination, $list_orderby, $list_order, $item_per_page, $list_style, $list_layout, $categories ) ; 

			}	

			//blog carousel
			elseif( $content_type == "blog_carousel" ){
			 
			 	/*
			 	//[blog_carousel id="" crop="" style="" heading="" heading_icon="" item_width="5" list_orderby="" list_order="" max_item="" categories="" ids="" display_excerpts=""]
			 	*/

			 	$crop = $style = $heading = $heading_icon = $item_width = $list_orderby = $list_order = $max_item = $categories = $display_excerpts =  $limit_chars = "";
			 	extract( $values );

			 	$blog_carousel_id = 'blog-carousel-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : "";

 				$template_output .=  sprintf('[blog_carousel id="%s" crop="%s" style="%s" heading="%s" heading_icon="%s" item_width="%s" list_orderby="%s" list_order="%s" max_item="%s" categories="%s" ids="%s" display_excerpts="%s" limit_chars="%s"]',
 					$blog_carousel_id, $crop, $style, $heading, $heading_icon, $item_width, $list_orderby, $list_order, $max_item, $categories, "", $display_excerpts,  $limit_chars ) ; 

			}	

			//portfolio box
			elseif( $content_type == "portfolio_box" ){
			 
			 	/*
			 	//[portfolio_box id="" item_width="5" pagination="" portf_list_orderby="" portf_list_order="" item_per_page="9" filterable="" categories=""  display_descriptions="" display_titles="" display_embedded_titles="" ]
			 	*/

			 	$categories = $display_descriptions = $display_titles = $pagination = $display_embedded_titles = $filterable = "";
			 	extract( $values );

			 	$portfolio_id = 'portfolio-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : "";

 				$template_output .=  sprintf('[portfolio_box id="%s" item_width="%s" pagination="%s" portf_list_orderby="%s" portf_list_order="%s" item_per_page="%s" filterable="%s" categories="%s" display_descriptions="%s" display_titles="%s" display_embedded_titles="%s"]',
 					$portfolio_id, $item_width, $pagination, $portf_list_orderby, $portf_list_order, $item_per_page, $filterable, $categories, $display_descriptions, $display_titles, $display_embedded_titles) ; 

			}	

			//product carousel
			elseif( $content_type == "portfolio_carousel" ){
			 
			 	/*
			 	//[portfolio_carousel id="" heading="" heading_icon="" item_width="5" list_orderby="" list_order="" max_item="9" categories="" portfolio_ids=""  display_descriptions="" display_titles=""]
			 	*/

			 	extract( $values );
			 	$crop = isset( $crop ) ? $crop : "";
			 	$display_descriptions = isset( $display_descriptions ) ? $display_descriptions : "";
			 	$display_titles = isset( $display_titles ) ? $display_titles : "";

			 	$portfolio_carousel_id = 'portfolio-carousel-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : "";

 				$template_output .=  sprintf('[portfolio_carousel id="%s" crop="%s" style="%s" heading="%s" heading_icon="%s" item_width="%s" list_orderby="%s" list_order="%s" max_item="%s" categories="%s" portfolio_ids="%s" display_descriptions="%s" display_titles="%s"]',
 					$portfolio_carousel_id, $crop, $style, $heading, $heading_icon, $item_width, $list_orderby, $list_order, $max_item, $categories, "", $display_descriptions, $display_titles ) ; 

			}	

			//product box
			elseif( $content_type == "product_box" ){
			 
			 	/*
			 	//[product_box id="" item_width="5" pagination="" list_orderby="" list_order="" item_per_page="9" categories="" display_descriptions="" display_titles="" display_price="" ]
			 	*/

			 	$heading = $crop = $categories = $display_descriptions = $display_titles = $display_price = $pagination = $with_borders = $with_effect = $no_top_border = $no_bottom_border = "";
			 	extract( $values );

			 	$product_id = 'products-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : ""; 

 				$template_output .=  sprintf('[product_box id="%s" item_width="%s" pagination="%s" list_orderby="%s" list_order="%s" item_per_page="%s" categories="%s"  display_descriptions="%s" display_titles="%s" display_price="%s" heading="%s" with_borders="%s" with_effect="%s" no_top_border="%s" no_bottom_border="%s"]',
 					$product_id, $item_width, $pagination, $list_orderby, $list_order, $item_per_page, $categories, $display_descriptions, $display_titles, $display_price, esc_attr($heading), $with_borders, $with_effect, $no_top_border, $no_bottom_border ); 

			}	

			//product carousel
			elseif( $content_type == "product_carousel" ){
			 
			 	/*
			 	//[product_carousel id="" heading="" heading_icon="" item_width="5" list_orderby="" list_order="" max_item="9" categories="" product_ids=""]
			 	*/

			 	extract( $values );
			 	$crop = isset( $crop ) ? $crop : "";

			 	$product_carousel_id = 'product-carousel-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$categories = isset( $categories ) && is_array( $categories ) ? implode($categories, ",") : "";

 				$template_output .=  sprintf('[product_carousel id="%s" crop="%s" style="%s" heading="%s" heading_icon="%s" item_width="%s" list_orderby="%s" list_order="%s" max_item="%s" categories="%s" product_ids="%s"]',
 					$product_carousel_id, $crop, $style, $heading, $heading_icon, $item_width, $list_orderby, $list_order, $max_item, $categories, "" ) ; 

			}	

			//google maps
			elseif( $content_type == "google_map" ){
			 
			 	/*
			 	//[google_maps map_id="" title="" height=""]
			 		[location title="" lat="" lon=""]text[/location] 
			 	[/google_maps]  
			 	*/
		 	
		 		$map_id = 'map-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
 
				//css for the map					 				
		 		$css_output["css_codes"] = $css_output["css_codes"]. sprintf("#%s{height:%spx}", $map_id, $height );

		 		$coords_output = "";
			 	foreach ($list["geo"] as $key => $options) {

			 		if( !empty( $list["geo"][$key] )){
						$geo            =  explode(",",$list["geo"][$key]);
						$location_text  = ! empty( $list["text"][$key] ) ? $list["text"][$key] : "";		
						$location_title = ! empty( $list["title"][$key] ) ? $list["title"][$key] : "";					 	
					 	 
					 	$coords_output .=  sprintf('[location title="%s" lat="%s" lon="%s"]%s[/location]',strip_tags($location_title), $geo[0], $geo[1], stripslashes($location_text) ) ; 
				 	}
			 	}

				$template_output .=  ! empty( $coords_output ) ? sprintf('[google_maps map_id="%s" height="%s" zoom="%s" title="%s" template_builder="true"]%s[/google_maps]', $map_id, $height, $zoom, strip_tags($module_title), $coords_output ) : ""; 
			}


			//contact form box
			elseif( $content_type == "contact_form" ){
			 
			 	/*
			 	//[contact_form title="" email="" text=""] 
			 	*/

				if ( empty( $shortcode ) ){
					$template_output .=  sprintf('[contact_form title="%s" email="%s"]%s[/contact_form] ',$title, $email, stripslashes($text)) ; 
				}else{
					$template_output .=  stripslashes($shortcode); 
				}	 				

			}				


			//banner box
			elseif( $content_type == "banner_box" ){
			 
			 	/*
			 	//[banner_box id="" text_icon="" text_alignment="" button_text="" button_icon="" button_link="" button_size="" link_target=""]text[/banner_box]
			 	*/

			 	$banner_id = 'banner-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
			 	$gradient = isset( $gradient ) ? $gradient : "";
			 	$border = isset( $border ) ? $border : "";

			 	extract( $values );

				if ( ! empty( $text ) ){ 
					$template_output .=  sprintf('[banner id="%s" gradient="%s" border="%s" text_icon="%s" text_alignment="%s" button_text="%s" button_icon="%s" button_link="%s" button_size="%s" link_target="%s"]%s[/banner]',
						$banner_id, $gradient, $border, $text_icon, $text_alignment, strip_tags( $button_text ), $button_icon, $button_link, $button_size, $link_target, stripslashes($text)) ; 
				}

				$border = $gradient = "";

			}				


			//code box
			elseif( $content_type == "code_box" ){
			 
				/*
				//[code_box box_id="" heading=""]code_space[/code_box]
				*/

				$box_id = 'code-box-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

				$template_output .=  sprintf('[code_box box_id="%s" heading="%s"]%s[/code_box]',
				$box_id, strip_tags($heading), stripslashes($code_space)) ; 

			}	

			//sidebar box
			elseif( $content_type == "sidebar_box" ){

				/*
				//[sidebar_box sidebar_id="sidebar-for-footer-column-4" widget_box_width="4"]
				*/ 

				if( $footer_started ){
					$location = "footer";
				}else{
					$location = "default";
				}

				$template_output .=  sprintf('[sidebar_box sidebar_id="%s" widget_box_width="%s" location="%s"]',
				$sidebar_id, $widget_box_width, $location ) ; 

			}		 

			//staff box
			elseif( $content_type == "staff_box" ){
			 
				/*
				//[staff_box id="" item_width="5" list_orderby="" list_order="" ids=""]
				*/

				$ids = $staff_box_id = $item_width = $list_orderby = $list_order = $style = $staff_ids = "";

				extract( $values );

				$staff_box_id = 'staff-list-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

				$staff_ids = isset( $ids ) && is_array( $ids ) ? implode($ids, ",") : "";

				$template_output .=  sprintf('[staff_box id="%s" item_width="%s" list_orderby="%s" list_order="%s" style="%s" ids="%s"]',
					$staff_box_id, $item_width, $list_orderby, $list_order, $style, $staff_ids) ; 

			}	


			//testimonial box
			elseif( $content_type == "testimonial_box" ){
			 
			 	/*
			 	//[testimonial_box id="" item_width="5" list_orderby="" list_order="" ids=""]
			 	*/

			 	$ids = $testimonial_box_id = $item_width = $list_orderby = $list_order = $style = $testimonial_ids = "";
			 	extract( $values );

			 	$testimonial_box_id = 'testimonials-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$testimonial_ids = isset( $ids ) && is_array( $ids ) ? implode($ids, ",") : "";

 				$template_output .=  sprintf('[testimonial_box id="%s" item_width="%s" list_orderby="%s" list_order="%s" style="%s" ids="%s"]',
 					$testimonial_box_id, $item_width, $list_orderby, $list_order, $style, $testimonial_ids) ; 

			}	

			//testimonial carousel
			elseif( $content_type == "testimonial_carousel" ){
			 
			 	/*
			 	//[testimonial_carousel id="" heading="" heading_icon="" item_width="5" list_orderby="" list_order="" ids=""]
			 	*/

			 	$ids = $testimonial_box_id = $heading = $heading_icon = $item_width = $list_orderby = $list_order = $testimonial_ids = $style = "";
			 	extract( $values );

			 	$testimonial_box_id = 'testimonial-carousel-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';

			 	$testimonial_ids = isset( $ids ) && is_array( $ids ) ? implode($ids, ",") : "";

 				$template_output .=  sprintf('[testimonial_carousel id="%s" heading="%s" heading_icon="%s" item_width="%s" list_orderby="%s" list_order="%s" ids="%s" style="%s"]',
 					$testimonial_box_id, $heading, $heading_icon, $item_width, $list_orderby, $list_order, $testimonial_ids, $style) ; 

			}	

			//WooCommerce Products
			elseif( $content_type == "woo_products_box" ){
			 
			 	/*
			 	//[product_category category="" per_page="12" columns="4" orderby="date" order="desc"]
			 	*/ 

 				$template_output .=  sprintf('[product_category category="%s" per_page="%s" columns="%s" orderby="%s" order="%s"]',
 					$categories, $item_per_page, $item_width, $list_orderby, $list_order) ; 

			}	
 
			//Layerslider
			elseif( $content_type == "layerslider_box" ){
			 
			 	/*
			 	//[layerslider id="1"]
			 	*/ 

 				$template_output .=  sprintf('[layerslider id="%s"]', $slider_id) ; 

			}	


			//Revolution slider
			elseif( $content_type == "revslider_box" ){
			 
			 	/*
			 	//[rev_slider aliasname]
			 	*/ 
 				$template_output .=  sprintf('[rev_slider %s]', $slider_id) ; 

			}	


			//space box
			elseif( $content_type == "space_box" ){
			 
			 	/*
			 	//[space_box id=""]
			 	*/
		 	
		 		$space_id = 'space-'.str_replace("templateid_", "", $templateID).'-'.$group_id.'';
 
				//css for the map					 				
		 		$css_output["css_codes"] = $css_output["css_codes"]. sprintf("#%s{height:%spx}", $space_id, $height );
 

				$template_output .=  ! empty( $height ) ? sprintf('[space_box id="%s" height="%s"]', $space_id, $height ) : ""; 
			}

			//other modules 
			else{
				$template_output .= rt_generate_shortcode($template);  
			}


			//close column holder for other elements than a column
			if ( ! $header_purpose && empty( $columns_started ) && $content_type != "column" && $content_type != "grid"  && $content_type != "slider_box" && $content_type != "space_box"){
				$template_output .= "[/rt_columns]";
			}


		} 

		return array( 'header' => $header_output, 'footer' => $footer_output, 'content' => $template_output, 'css' => $css_output, "template_options" => $template_options );
	}	 

	#
	#	Create Default Templates
	#
	function rt_create_default_templates(){
		
		//reset
		$defaultTemplates  = array();
		update_option(RT_THEMESLUG.'_template_names_array', $defaultTemplates); 		
		
		//get the default tempalates data
		require_once(RT_THEMEFRAMEWORKDIR . "/admin/default_templates/index.php");  	
 
		$this->rt_import_page_templates( $default_templates );

	}

	#
	#	Delete All Templates
	#
	function rt_delete_templates( $selectedTemplate = "" ){
		
 		//get the saved template names
		$saved_template_names = get_option(RT_THEMESLUG.'_template_names_array');

		if( is_array( $saved_template_names ) ){
			//create default templates 
			foreach ($saved_template_names as $templateID => $templateData) {

				//check if a template specified
				if ( ! empty( $selectedTemplate ) ) {

					//delete the template name from the array
					unset($saved_template_names[ $selectedTemplate ]);
					update_option(RT_THEMESLUG.'_template_names_array', $saved_template_names);

					$templateID = $selectedTemplate;
				}

				//delete the template data
				delete_option( RT_THEMESLUG."_".$templateID );

				//delete header output
				delete_option( RT_THEMESLUG."_".$templateID."_header_output" );							

				//delete footer output
	 			delete_option( RT_THEMESLUG."_".$templateID."_footer_output" ); 
	 
				//delete content output
	 			delete_option( RT_THEMESLUG."_".$templateID."_content_output" ); 
	 
				//delete css output
				delete_option( RT_THEMESLUG."_".$templateID."_css_output" );
				 
				//delete template options
				delete_option( RT_THEMESLUG."_".$templateID."_template_options");

				//check if a template specified then stop the loop
				if ( ! empty( $selectedTemplate ) ) {
					break;
				}
			}
		} 
	}

	#
	#	Create Grid
	#
	function rt_generate_grid($theGroupID,$theTemplateID,$options,$randomClass){    
			global $rt_sidebars_class;
			$saved_options = $options;

			$boxName                = __("Grid", "rt_theme_admin");
			$contet_type            = "grid";			
			$theTemplateID          = str_replace('_'.$contet_type,'',$theTemplateID);   
			$part                   = isset( $options['part'] ) ? $options['part'] : 'full' ;  			
			$header_options         = isset( $options['header_options'] ) ? $options['header_options'] : "default" ;  
			$background_options     = isset( $options['background_options'] ) ? $options['background_options'] : "default" ;  
			$background_image_url   = isset( $options['background_image_url'] ) ? $options['background_image_url'] : "" ;  
			$background_color       = isset( $options['background_color'] ) ? $options['background_color'] : "" ;  
			$background_position    = isset( $options['background_position'] ) ? $options['background_position'] : "" ;  
			$background_repeat      = isset( $options['background_repeat'] ) ? $options['background_repeat'] : "" ;  
			$background_attachment  = isset( $options['background_attachment'] ) ? $options['background_attachment'] : "" ;  
			$sidebar_id             = isset( $options['sidebar_id'] ) ? $options['sidebar_id'] : "" ;   
			$sidebar_selection      = isset( $options['sidebar_selection'] ) ? $options['sidebar_selection'] : "full" ;   			
			$breadcrumb_position    = isset( $options['breadcrumb_position'] ) ? $options['breadcrumb_position'] : "full" ;  
			$first_top_widget_name  = isset( $options['first_top_widget_name'] ) ? $options['first_top_widget_name'] : "sidebar-for-top-first" ;  
			$second_top_widget_name = isset( $options['second_top_widget_name'] ) ? $options['second_top_widget_name'] : "sidebar-for-top-second" ;  
			$isNewBox               = isset( $options['newtemplate'] ) && $options['newtemplate']=="true"  ? true : false;
			$breadcrumb             = isset( $options['breadcrumb'] )  || ( isset( $options['breadcrumb'] ) && empty( $options['breadcrumb'] ) ) ? $options['breadcrumb'] : 1 ;    
			$page_title             = isset( $options['page_title'] ) ? $options['page_title'] : "" ;   
			$display_widgets        = isset( $options['display_widgets'] ) ? $options['display_widgets'] : "" ;   
			$header_purpose         = isset( $options['header_purpose'] ) ? $options['header_purpose'] == true || $options['header_purpose'] == "1" ? true : false : false; 			
			$footer_purpose         = isset( $options['footer_purpose'] ) ? $options['footer_purpose'] == true || $options['footer_purpose'] == "1" ? true : false : false; 			
			$div_header_class       = isset ( $header_options ) && $header_options == "new" ? 'header_background_options active' : "header_background_options";
			$div_row_class          = isset ( $background_options ) && $background_options == "new" ? 'header_background_options active' : "header_background_options";
			$sidebar_selector_class = $isNewBox || $sidebar_selection=="full" ? 'sidebar_selection_list' : "sidebar_selection_list active";

			$padding_left           = isset( $options['column_options'] ) && isset( $options['column_options']['padding_left'] ) ? $options['column_options']['padding_left'] : "0";
			$padding_right          = isset( $options['column_options'] ) && isset( $options['column_options']['padding_right'] ) ? $options['column_options']['padding_right'] : "0";
			$padding_top            = isset( $options['column_options'] ) && isset( $options['column_options']['padding_top'] ) ? $options['column_options']['padding_top'] : "0";
			$padding_bottom         = isset( $options['column_options'] ) && isset( $options['column_options']['padding_bottom'] ) ? $options['column_options']['padding_bottom'] : "0";
 
			$row_padding_left           = isset( $options['row_style_options'] ) && isset( $options['row_style_options']['padding_left'] ) ? $options['row_style_options']['padding_left'] : "0";
			$row_padding_right          = isset( $options['row_style_options'] ) && isset( $options['row_style_options']['padding_right'] ) ? $options['row_style_options']['padding_right'] : "0"; 
			$row_padding_top            = isset( $options['row_style_options'] ) && isset( $options['row_style_options']['padding_top'] ) ? $options['row_style_options']['padding_top'] : "20";
			$row_padding_bottom         = isset( $options['row_style_options'] ) && isset( $options['row_style_options']['padding_bottom'] ) ? $options['row_style_options']['padding_bottom'] : "20";
 


			//first part of the row 		
			if($part == "first" || $part == "full" ) {

				//row class
				if( $header_purpose == "true" ){ // header row
					$row_class_name = "header_content_row";
				}elseif( $footer_purpose == "true" ){ // footer row
					$row_class_name = "footer_content_row";
				}else{
					$row_class_name = "content_row";
				}
 		  
				//close content rows holder - before footer row
				if( $footer_purpose == "true" && $part == "first"){  
					echo  '</div>';
				} 

				//row holder
				echo '<div class="grid_holder grid_'.$theTemplateID.' '.$row_class_name.'">'; 				

				if( $header_purpose == "true" ){ // header row
  
					echo '<div class="grid_options"> 
							<span class="row_title icon-right-open">'.__("Header Row",'rt_theme_admin').'</span>
							<span class="grid_options_button header active"><span class="icon-plus-squared"></span> '.__("Show Header Options",'rt_theme_admin').'</span>
							<span class="grid_options_button header hide hidden"><span class="icon-minus-squared"></span>  '.__("Hide Header Options",'rt_theme_admin').'</span> 
						</div>';						
				
				}elseif( $footer_purpose == "true" ){ // footer row 

					echo '<div class="grid_options"> 
							<span class="row_title icon-right-open">'.__("Footer Row",'rt_theme_admin').'</span>
							<span class="grid_options_button header active"><span class="icon-plus-squared"></span> '.__("Show Footer Options",'rt_theme_admin').'</span>
							<span class="grid_options_button header hide hidden"><span class="icon-minus-squared"></span>  '.__("Hide Footer Options",'rt_theme_admin').'</span> 
						</div>';						
																							
				}else{ // options and delete buttons - content row
 
					
					echo '<div class="row_delete" title="'.__('Delete Row','rt_theme_admin').'"></div>';
					echo '<div class="grid_options"> 
							<span class="row_title icon-right-open">'.__("Content Row",'rt_theme_admin').'</span>
							<span class="grid_options_button active"><span class="icon-plus-squared"></span> '.__("Show Row Options",'rt_theme_admin').'</span>
							<span class="grid_options_button hide hidden"><span class="icon-minus-squared"></span>  '.__("Hide Row Options",'rt_theme_admin').'</span> 
						</div>';					
				} 

				echo '<div class="grid_options_hidden">';


				if( $header_purpose == "true" ){ // header row options

					$options = array (  	 
  
							array(
								"name" => __("BREADCRUMB & TITLE",'rt_theme_admin'), 
								"type" => "heading"),	


							array(
								"name"    => __("Breadcrumb & Title Position",'rt_theme_admin'),
								"desc"    => __('Select a position for the breadcrumb menu path and the page title.','rt_theme_admin'),
								"id"      => $theTemplateID.'_'.$theGroupID."_grid[breadcrumb_position]",   
								"options" =>  array(
												"inside_header"  =>  "Inside Header Bar", 
												"inside_content" =>  "Inside Content Area",
											),
								"value"	  => $breadcrumb_position,
								"default" => "inside_header",
								"type"    => "select"
							),	

							array(
								"name" 		=> __("Show Breadcrumb Menu",'rt_theme_admin'),
								"desc"    => __('Enable (if checked) the breadcrumb menu path for this page.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_grid[breadcrumb]",    
								"class"		=> $randomClass, 
								"check_desc"=> __('Show breadcrumb menu for this template','rt_theme_admin'),
								"value"		=> $isNewBox ? "on" : $breadcrumb,
								"type" 		=> "checkbox"						
							),  						

							array(
								"name" 		=> __("Show Page Title",'rt_theme_admin'),
								"desc"    => __('Enabled (if checked) displaying the title for this page.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_grid[page_title]",    
								"class"		=> $randomClass, 
								"check_desc"=> __('Display the page / post title.','rt_theme_admin'),
								"value"		=> $isNewBox ? "on" : $page_title,
								"type" 		=> "checkbox"						
							),  		

							array(
								"name" => __("TOP WIDGET AREAS",'rt_theme_admin'), 
								"type" => "heading"),	

							array(
								"name" 		=> __("First Top Widget Area",'rt_theme_admin'),
								"desc"		=> __("Select / set the first sidebar container area you want to display within this template area (row)",'rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_grid[first_top_widget_name]",
								"select"    =>__("Select",'rt_theme_admin'),
								"options"	=> $rt_sidebars_class->rt_active_sidebars,
								"class"		=> $randomClass,
								"value"		=> $first_top_widget_name, 
								"type" 		=> "select"
							),

							array(
								"name" 		=> __("Second Top Widget Area",'rt_theme_admin'),
								"desc"		=> __("Select / set the second sidebar container area that you want to display within this template area (row)",'rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_grid[second_top_widget_name]",
								"select"    =>__("Select",'rt_theme_admin'),
								"options"	=> $rt_sidebars_class->rt_active_sidebars,
								"class"		=> $randomClass,
								"value"		=> $second_top_widget_name, 
								"type" 		=> "select"
							),
					);

				//get styling options
				$options = array_merge( $options,  $this->rt_generate_grid_background_options($theGroupID,$theTemplateID,$saved_options,$randomClass, "header" ) ) ;
				
			
				}elseif( $footer_purpose == "true" ){ // footer row options

					$options = array (  	 
 
 							array(
								"name" => __("DEFAULT FOOTER WIDGETS",'rt_theme_admin'), 
								"type" => "heading"),	

							array(
								"name" 		=> __("Display Default Widgets",'rt_theme_admin'),
								"desc"		=> __("Turn OFF/ON visibility of the default footer widgets for this page.","rt_theme_admin"),
								"id"        => $theTemplateID.'_'.$theGroupID."_grid[display_widgets]",    
								"class"		=> $randomClass, 
								"value"		=> $isNewBox ? "on" : $display_widgets,
								"type" 		=> "checkbox2"						
							),  		

					);
				
				//get styling options
				$options = array_merge( $options,  $this->rt_generate_grid_background_options($theGroupID,$theTemplateID,$saved_options,$randomClass, "footer" ) ) ;

				}else{//content row options

					$options = array (  	 

							array(
								"desc"   => "Row ID: #row-".str_replace('templateid_','',$theTemplateID).'-'.$theGroupID,
								"type"    => "info" 
							),

							array(
								"name"    => __("Sidebar Location",'rt_theme_admin'),
								"desc"      => __('Select and set the layout for this template container (row).','rt_theme_admin'),								
								"id"      => $theTemplateID.'_'.$theGroupID."_grid[sidebar_selection]", 
								"options" => array("full"=>"No Sidebar","left"=>"Left Sidebar","right"=>"Right Sidebar"), 
								"value"   => $sidebar_selection,  
								"purpose" => "page_layouts", 
								"class"   => "layout_selector",
								"type"    => "radio" 
							),

							array(
								"id"      	=> $theTemplateID."_sidebar_hidden_div_start",
								"div_class"	=> $sidebar_selector_class,
								"type"    	=> "div_start" 
							), 

							array(
								"name" 		=> __("Select Sidebar (Widget Area)",'rt_theme_admin'),
								"desc"		=> __("Select and set the sidebar container area that you want to display for this template container (row)",'rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_grid[sidebar_id][]",
								"options"	=> $rt_sidebars_class->rt_active_sidebars,
								"class"		=> $randomClass,
								"value"		=> $sidebar_id,  
								"type" 		=> "selectmultiple"
							),

							array(
								"id"	=> $theTemplateID."_sidebar_hidden_div_end",
								"type"	=> "div_end" 
							), 

							//COLUMN OPTIONS
							array(	 
								"type"    => "div_start",
								"div_class"   => "options_set_holder",
							),	  				


								array(
								"name" 		=> __("ROW STYLE",'rt_theme_admin'), 
								"type" 		=> "heading"),		


								array(
								"name"      => __("Row Width",'rt_theme_admin'),
								"desc"      => __('Select and set the width for this template container (row). When set to &#39;full width&#39; the row can contain f.e. a full width (flex) slider or google map. <strong>Note</strong> : Be do adviced to set this <strong>NOT</strong> to &#39;full width row&#39; for listing your normal page content (products, portfolio, blogpost etc).','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_grid[row_style_options][row_width]",    
								"options"   =>  array(
									"default"   => __("Content Width",'rt_theme_admin'),
									"full" 		=> __("Window Width (100%)",'rt_theme_admin'),
									), 
								"dont_save" => "true",
								"type"      => "select", 
								"class"		=> "row_width",
								"value"		=> isset( $options['row_style_options'] ) && isset( $options['row_style_options']['row_width'] ) ? $options['row_style_options']['row_width'] : "default",
								),	 
			 

								array(
								"name" 		=> __("ROW PADDINGS (px)",'rt_theme_admin'), 
								"type" 		=> "heading"),		

								array( 
									"layout"   => "four",
									"type"    => "col_start", 
									"holder_class" => "option_paddings paddings box_border",
								),

								array(
										"name" => __("Padding Left",'rt_theme_admin'),
										"desc" => __('Set the left padding in pixels.','rt_theme_admin'),										
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[row_style_options][padding_left]",    
										"value"=> $row_padding_left,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"     => "col_split", 
								),

								array(
										"name" => __("Padding Right",'rt_theme_admin'),
										"desc"      => __('Set the right padding in pixels.','rt_theme_admin'),																				
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[row_style_options][padding_right]",    
										"value"	=> $row_padding_right,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"    => "col_split", 
								),

								array(
										"name" => __("Padding Top",'rt_theme_admin'),
										"desc"      => __('Set the top padding in pixels.','rt_theme_admin'),																				
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[row_style_options][padding_top]",    
										"value"	=> $row_padding_top,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"    => "col_split", 
								),

								array(
										"name" => __("Padding Bottom",'rt_theme_admin'),
										"desc"      => __('Set the bottom padding in pixels.','rt_theme_admin'),										
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[row_style_options][padding_bottom]",    
										"value"	=> $row_padding_bottom,
										"type" => "text"
								),								
								array(	 
									"type"    => "col_end"
								),			


								array(
								"name" 		=> __("COLUMN PADDINGS (px)",'rt_theme_admin'), 
								"type" 		=> "heading"),		

								array( 
									"layout"   => "four",
									"type"    => "col_start", 
									"holder_class" => "option_paddings paddings box_border",
								),

								array(
										"name" => __("Padding Left",'rt_theme_admin'),
										"desc"      => __('Set the left padding in pixels.','rt_theme_admin'),										
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[column_options][padding_left]",    
										"value"	=> $padding_left,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"    => "col_split", 
								),

								array(
										"name" => __("Padding Right",'rt_theme_admin'),
										"desc"      => __('Set the right padding in pixels.','rt_theme_admin'),																				
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[column_options][padding_right]",    
										"value"	=> $padding_right,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"    => "col_split", 
								),

								array(
										"name" => __("Padding Top",'rt_theme_admin'),
										"desc"      => __('Set the top padding in pixels.','rt_theme_admin'),																				
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[column_options][padding_top]",    
										"value"	=> $padding_top,
										"type" => "text"
								),

								array( 
									"layout"   => "four",
									"type"    => "col_split", 
								),

								array(
										"name" => __("Padding Bottom",'rt_theme_admin'),
										"desc"      => __('Set the bottom padding in pixels.','rt_theme_admin'),										
										"id"   => $theTemplateID.'_'.$theGroupID."_grid[column_options][padding_bottom]",    
										"value"	=> $padding_bottom,
										"type" => "text"
								),								
								array(	 
									"type"    => "col_end"
								),	

								array(
								"name" 		=> __("COLUMN BACKGROUND",'rt_theme_admin'), 
								"type" 		=> "heading"),		


								array(
								"name"      => __("Column Background",'rt_theme_admin'),
								"desc"      => __('Select and set a default column background color for this template container (row).','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_grid[column_options][background_selection]",    
								"options"   =>  array(
									"default"          => __("Default",'rt_theme_admin'),
									"half_transparent" => __("Transparent-White",'rt_theme_admin'),
									"new"              => "Select Color",
									), 
								"dont_save" => "true",
								"type"      => "select", 
								"value"		=> isset( $options['column_options'] ) && isset( $options['column_options']['background_selection'] ) ? $options['column_options']['background_selection'] : "default",
								"class"     => "div_controller",
								),	 
			 
								array( 
									"div_class"   => "hidden_options_set",
									"type"    => "div_start", 
								),

									array(
									"name"      => __("Column Background Color",'rt_theme_admin'),
									"desc" 		=> __('Click within the color field or on the circular element of the color field to open up the colorpicker. In the colorpicker select a color by dragging the circular object within the colorgrid. You can also insert manually a valid html color code. If you would like to turn back to the default color, just delete the value and make sure to save the settings.','rt_theme_admin'),
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[column_options][background_color]",    
									"dont_save" => "true",
									"value"		=> isset( $options['column_options'] ) && isset( $options['column_options']['background_color'] ) ? $options['column_options']['background_color'] : "#ffffff",
									"type"      => "colorpicker"),		

								array(	 
									"type"    => "div_end"
								),				 							



							array(	 
								"type"    => "div_end"
							),	
					);
	
				//get styling options
				$options = array_merge( $options,  $this->rt_generate_grid_background_options($theGroupID,$theTemplateID,$saved_options,$randomClass,"ca1") ) ;			 
 
				}

				echo  $this->rt_generate_forms($options,$theTemplateID); 				
				echo '</div>'; 
			}   

			if( $header_purpose ){ // header row
				$options = array (  

						array(
								"id"      => $theTemplateID.'_'.$theGroupID."_grid[grid]",
								"type"    => "grid",
								"purpose" => "page_template",
								"value"   => $part,
								"part"    => $part,
								"header_purpose" => true,
								"footer_purpose" => false  
							)
				);
			}elseif( $footer_purpose ){ // footer row
				$options = array (  

						array(
								"id"      => $theTemplateID.'_'.$theGroupID."_grid[grid]",
								"type"    => "grid",
								"purpose" => "page_template",
								"value"   => $part,
								"part"    => $part,
								"header_purpose" => false, 
								"footer_purpose" => true, 
							)
				);				
			}else{
				$options = array (  

						array(
								"id"      => $theTemplateID.'_'.$theGroupID."_grid[grid]",
								"type"    => "grid",
								"purpose" => "page_template",
								"value"   => $part,
								"part"    => $part,
								"header_purpose" => false,
								"footer_purpose" => false  
							)
				);				
			}

			echo  $this->rt_generate_forms($options,$theTemplateID); 

			//close rows  
			if($part == "second" || $part == "full" ){
				echo  '</div>';
			}

			//start content rows holder - after hader row
			if( $header_purpose == "true" && $part == "second"){  
				echo  '<div class="start_content_rows">';
			} 
	}	

	function rt_generate_grid_background_options($theGroupID,$theTemplateID,$options,$randomClass,$default){    
	
		$background_repeat = $background_attachment = $background_size = $background_position = $background_color = $background_image_url = $background_selection = $social_media = $highlighted = $border = $link_hover = $link = $heading_links = $headings = $light_font = $font = $primary = $color_set_selection = "";
		$color_set	= isset( $options['color_set'] ) && is_array( $options['color_set'] )  ? $options['color_set'] : array() ;   
		$background_options	= isset( $options['background_options'] ) && is_array( $options['background_options'] )  ? $options['background_options'] : array() ; 	 	
		$colorpickerdescription = __('Click within the color field or on the circular element of the color field to open up the colorpicker. In the colorpicker select a color by dragging the circular object within the colorgrid. You can also insert manually a valid html color code. If you would like to turn back to the default color, just delete the value and make sure to save the settings.','rt_theme_admin');

		extract( $color_set );  
		extract( $background_options );

		$color_set_selection = !empty( $color_set_selection ) ? $color_set_selection :  $default ;	
		$background_selection = !empty( $background_selection ) ? $background_selection :  $default ;	
		
		$options = array (  	 

			array(	 
				"type" => "div_start",
				"id"   => "rttheme-tab-2",
			),	  

				//COLOR SET
				array(	 
					"type"        => "div_start",
					"div_class"   => "color_set options_set_holder",
				),	  				

					array(
					"name"      => __("COLOR SETTINGS",'rt_theme_admin'), 
					"type"      => "heading"),		


					array(
					"name"      => __("Color Style",'rt_theme_admin'),
					"desc"    => __('Select and set a default color style as set in the theme styling options or create a new one.','rt_theme_admin'),								
					"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][color_set_selection]",    
					"options"   => array(
										"optgroup_start 1"=>"Theme Defaults",
											"default"  => __("Use theme defaults",'rt_theme_admin'), 						
										"optgroup_end 1"=>"",
										
										"optgroup_start 2"=>"Create a custom color set",
											"new"      => "Custom",								
										"optgroup_end 2"=>"",

										"optgroup_start 3"=>"Use global color set of",
											"ca1"  => __("Default Content Area ",'rt_theme_admin'),		
											"ca2"  => __("Alternate Content Area 1 ",'rt_theme_admin'),							
											"ca3"  => __("Alternate Content Area 2",'rt_theme_admin'),
											"header"  => __("Sub-Header Area ",'rt_theme_admin'),
											"footer"  => __("Footer Area",'rt_theme_admin'),
										"optgroup_end 3"=>"",			
										),   
					"dont_save" => "true",
					"type"      => "select", 
					"value"		=> $color_set_selection,
					"class"     => "div_controller",
					),	 


					array( 
						"div_class"   => "hidden_options_set",
						"type"    => "div_start",

					),

									array(							
									"type" 		=> "col_start",
									"holder_class" => "box_border paddings heading_size",
									"layout" 	=> "two"
									),
											
									array(
									"name"      => __("Primary Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][primary]",    
									"dont_save" => "true", 
									"value"		=> $primary,
									"type"      => "colorpicker"),

									array(
									"name"      => __("Content Font Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][font]",    
									"dont_save" => "true", 
									"value"		=> $font,
									"type"      => "colorpicker"),								

									array(
									"name"      => __("Secondary Content Font Color (Lighter)",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][light_font]",    
									"dont_save" => "true", 
									"value"		=> $light_font,
									"type"      => "colorpicker"),


									array(
									"name"      => __("Headings Font Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][headings]", 
									"dont_save" => "true",
									"value"		=> $headings,
									"type"      => "colorpicker"),

									array(
									"name"      => __("Headings With Links (Hover Stage)",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][heading_links]",    
									"dont_save" => "true",
									"value"		=> $heading_links,
									"type"      => "colorpicker"), 
									
									array(							
									"type" 		=> "col_split",
									"layout" 	=> "two"
									),

									array(
									"name"      => __("Custom Link Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][link]", 
									"dont_save" => "true",
									"value"		=> $link,
									"type"      => "colorpicker"),
									
									array(
									"name"      => __("Custom Link Color (Hover State)",'rt_theme_admin'), 
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][link_hover]", 
									"dont_save" => "true",
									"value"		=> $link_hover,
									"type"      => "colorpicker"),		 
		 
									array(
									"name"      => __("Border Color",'rt_theme_admin'), 
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][border]", 
									"dont_save" => "true",
									"value"		=> $border,
									"type"      => "colorpicker"),		  

									array(
									"name"      => __("Highlighted Background Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][highlighted]",  
									"dont_save" => "true",
									"value"		=> $highlighted,
									"type"      => "colorpicker"),
		 
									array(
									"name"      => __("Social Media Icons Base Color",'rt_theme_admin'), 
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[color_set][social_media]",   
									"dont_save" => "true",
									"value"		=> $social_media,
									"type"      => "colorpicker"),		
		 
		 							array(							
									"type" 		=> "col_end"
									),

					array(	 
						"type"    => "div_end"
					),				 							
 

				array(	 
					"type"    => "div_end"
				),	


				//BACKGROUND
				array(	 
					"type"    => "div_start",
					"div_class"   => "color_set options_set_holder",
				),	  				

					array(
					"name" 		=> __("BACKGROUND SETTINGS",'rt_theme_admin'), 
					"type" 		=> "heading"),		 

					array(
					"name"      => __("Background Style",'rt_theme_admin'),
					"desc"    => __('Select and set a default background style as set in the theme styling options or create a new one.','rt_theme_admin'),								
					"id"        =>  $theTemplateID.'_'.$theGroupID."_grid[background_options][background_selection]",    
					"options"   => array( 
										"optgroup_start 1"=>"Theme Defaults",
											"default"  => __("Use theme defaults",'rt_theme_admin'), 						
										"optgroup_end 1"=>"",
										
										"optgroup_start 2"=>"Create a custom background",
											"new"      => "Custom",								
										"optgroup_end 2"=>"",

										"optgroup_start 3"=>"Use global background of",
											"ca1"  => __("Default Content Area ",'rt_theme_admin'),		
											"ca2"  => __("Alternate Content Area 1 ",'rt_theme_admin'),							
											"ca3"  => __("Alternate Content Area 2",'rt_theme_admin'),
											"header"  => __("Sub-Header Area ",'rt_theme_admin'),
											"footer"  => __("Footer Area",'rt_theme_admin'),
										"optgroup_end 3"=>"",		
										),   
					"dont_save" => "true",					
					"type"      => "select", 
					"value"		=> $background_selection,
					"class"     => "div_controller",
					),	 


					array( 
						"div_class"   => "hidden_options_set",
						"type"    => "div_start",

					), 

									array(
									"name"      => __("Background Image",'rt_theme_admin'),
									"desc"      => __('Please add a image by the use of the upload button or insert a valid url to a image to use as a background. <strong>Note</strong> : Externally linked images are not allowed because they can put your website at risk.','rt_theme_admin'),
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_image_url]",  
									"value"		=> $background_image_url,  
									"type"      => "upload"),

									array(
									"name"      => __("Background Color",'rt_theme_admin'),
									"desc" 		=> $colorpickerdescription,
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_color]",    
									"value"		=> $background_color,
									"type"      => "colorpicker"),
									 
									array(
									"name"      => __("Position",'rt_theme_admin'),
									"desc"      => __('Select and set alignment for the background image.','rt_theme_admin'),									
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_position]",    
									"options"	=> array(		
														"right top"     => "Right Top",
														"right center"  => "Right Center",
														"right bottom"  => "Right Bottom",
														"left top"      => "Left Top",
														"left center"   => "Left Center",
														"left bottom"   => "Left Bottom",
														"center top"    => "Center Top",
														"center center" => "Center Center",
														"center bottom" => "Center Bottom",
													),  
									"value"		=> $background_position,
									"type"      => "select"),

									array(
									"name"      => __("Repeat",'rt_theme_admin'),
									"desc"      => __('Select and set repeat mode direction for the background image.','rt_theme_admin'),									
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_repeat]",    
									"options"   => array(		
													"repeat"       =>"Tile",
													"repeat-x"     =>"Tile Horizontally",
													"repeat-y"     =>"Tile Vertically",
													"no-repeat"    =>"No Repeat"
													),  
									"type"      => "radio",
									"value"		=> $background_repeat,
									"default"	=> "repeat"
									),

									array(
									"name"      => __("Attachment",'rt_theme_admin'),
									"desc"      => __('Select and set fixed or scroll mode for the background image.','rt_theme_admin'),									
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_attachment]",    
									"options"   => array(		
													"scroll"        =>"Scroll",
													"fixed"         =>"Fixed"  
													),  
									"default"	=> "scroll",
									"value"		=> $background_attachment,
									"type"      => "radio"
									),  

									array(
									"name"      => __("Background Size",'rt_theme_admin'),
									"desc"      => __('Select and set size / coverage behaviour for the background image.','rt_theme_admin'),									
									"id"        => $theTemplateID.'_'.$theGroupID."_grid[background_options][background_size]",   
									"options"   => array(		
													"auto auto" =>"Auto",  
													"cover" =>"Cover",
													"contain" =>"Contain",
													"100% auto" =>"100%",
													"50% auto" =>"50%",  
													"25% auto" =>"25%",  
													),  
									"value"		=> $background_size,
									"type"      => "select"
									),  

					array(	 
						"type"    => "div_end"
					),				 							
 

				array(	 
					"type"    => "div_end"
				),	
 

			array(	 
				"type"    => "div_end"
			)

		);

		return $options;		 
	}	

	#
	#	Create Columns
	#
	function rt_generate_column($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName       = __("Column", "rt_theme_admin");
			$contet_type   = "column";			
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$part          = isset( $options['part'] ) ? $options['part'] : 'full' ;
			$layout        = isset( $options['layout'] ) ? $options['layout'] : '1' ; 


				$options = array (  

						array(
								"id"      => $theTemplateID.'_'.$theGroupID."_column[column]",
								"type"    => "column",
								"purpose" => "page_template",
								"value"   => $part,
								"part"    => $part,
								"layout"  =>  $layout
							)
				);

						echo  $this->rt_generate_forms($options,$theTemplateID); 
	}		

	function module_controls( $isNewBox ){

		return $module_controls ='
			<div class="module_controls">
				<span class="icon-pencil-1 module_edit" title="'.__("Edit", "rt_theme_admin").'"></span> 
				<span class="icon-move module_move"></span>   
				<span class="icon-clipboard module_copy" title="'.__("Copy", "rt_theme_admin").'"></span>	
				<span class="icon-docs-1 module_clone" title="'.__("Clone", "rt_theme_admin").'"></span>	
				<span class="icon-trash-1 module_delete" title="'.__("Delete", "rt_theme_admin").'"></span>				
				<span class="icon-cancel module_close" title="'.__("Close", "rt_theme_admin").'"></span>			
			</div>
		';
	}

	#
	#	Heading Bar
	#
	function rt_generate_heading_bar($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName       = __("Heading Bar", "rt_theme_admin");
			$contet_type   = "heading_bar";			
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;';	 
			$heading       = isset( $options['heading'] ) ? $options['heading'] : "";  
			$icon          = isset( $options['icon'] ) ? $options['icon'] : "";  
			$style         = isset( $options['style'] ) ? $options['style'] : "";  


			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
			
			$options = array (
  
						array(
								"desc" => __("Use this module to display a heading bar with an icon (optional).",'rt_theme_admin'),	 
								"hr"   => "true",
								"type" => "info"),
 
						array(
								"name"  => __("Heading",'rt_theme_admin'),
								"desc"      => __('Enter a heading title.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_heading_bar[heading]",
								"value" => $heading,
								"class" => "heading",
								"type"  => "text"),

						array(
								"name"  => __("Icon",'rt_theme_admin'), 
								"desc"      => __('Select a icon to precede the title (heading).','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_heading_bar[icon]",
								"value" => $icon,
								"class" => 'icon_selection', 
								"type"  => "text"),

						array(
								"name"  => __("Style",'rt_theme_admin'),
								"desc"      => __('Select and set text alignment of the banner text.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_heading_bar[style]",
								"options" => array(
													"" => "Style 1",
													"style-2" => "Style 2", 
												),
								"default" => "left",
								"value"   => $style, 
								"type"    => "select"),		
			);


			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Space Box
	# 
	function rt_generate_space_box($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName       = __("Space Box", "rt_theme_admin");
			$contet_type   = "space_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;  
			$height        = isset( $options["height"] ) ? $options["height"] : "" ;
		
			echo '<li class="ui-state-default '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
	 
						array(
								"desc" => __("The space box wil create a space, a empty room between modules, at the location where the box is inserted in the template with a height as set in the space box height setting.",'rt_theme_admin'),	 
								"hr" => "true",
								"type" => "info"),  
								
 						array(
								"name" 		=> __("Space Box Height (px)",'rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_space_box[height]",
								"desc" 		=> __("<strong>Space Box Height (px)</strong> : Set the height for the space box in pixels by dragging the horizontal (scroll) bar to the left or right to decrease or increase the height value or by directly inputting a height value into the text field.",'rt_theme_admin'),
								"hr" 		=> "true",
								"min"		=> "0",
								"max"		=> "500",
								"default"	=> "0",
								"hr"		=> true,
								"dont_save"	=> true,
								"value"		=> $height,
								"class"		=> $randomClass,
								"type"		=> "rangeinput"),  								
 
					);
										
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}		 

	#
	#	Banner Box
	#
	function rt_generate_banner_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Banner Box", "rt_theme_admin");
			$contet_type   = "banner_box";			
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;			
			$values        = isset( $options['values'] ) ? $options['values'] : array();  

			$border  = $gradient = $text_icon = $text_alignment = $button_text = $button_icon = $button_size = $button_link  = $link_target = $text = "";
			extract($values);

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
			
			$options = array ( 

						array(
								"desc" => __("You can use this module to display a banner box.",'rt_theme_admin'),	 
								"type" => "info"),


						array( 
								"type"   => "table_start"),


						array(
								"name" 		=> __("BANNER TEXT",'rt_theme_admin'),	  
								"type" 		=> "heading"), 					

						array(
								"name"  => __("Banner Text",'rt_theme_admin'),
								"desc"      => __('Enter the text to show within the banner. Simple html is allowed.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][text]",
								"value" => $text,
								"class" => "banner_text", 
								"type"  => "textarea"),	

						array(
								"name"  => __("Text Icon",'rt_theme_admin'), 
								"desc"  => __('Select and set a icon to precede the banner text.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][text_icon]",
								"value" => $text_icon,
								"class" => 'icon_selection', 
								"type"  => "text"),

						array(
								"name"  => __("Text Alignment",'rt_theme_admin'),
								"desc"      => __('Select and set text alignment of the banner text.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][text_alignment]",
								"options" => array(
													"left"   => "Left",
													"center" => "Center", 
												),
								"default" => "left",
								"value"   => $text_alignment, 
								"type"    => "select"),

						array(
								"name" 		=> __("BANNER STYLE",'rt_theme_admin'),	  
								"type" 		=> "heading"), 					

						array(
								"name" 	=> __("Border (if checked a border will show around the banner text)",'rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][border]", 
								"value" => $border, 
								"type" 	=> "checkbox2"),			

						array(
								"name" 	=> __("Gradient (if checked a gradient background will show behind the banner box)",'rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][gradient]", 
								"value" => $gradient, 
								"type" 	=> "checkbox2"), 

						array( 
								"type"   => "td_col"),

						array(
								"name"    => __("BUTTON",'rt_theme_admin'),	  
								"type"    => "heading"), 					
				 
	 
						array(
								"name"  => __("Button Text",'rt_theme_admin'),
								"desc"  => __('Enter the text to show within the button.','rt_theme_admin'),								
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][button_text]",
								"value" => $button_text,
								"class" => "button_text", 
								"type"  => "text"),

						array(
								"name"  => __("Button Icon",'rt_theme_admin'), 
								"desc"  => __('Select and set a icon to precede the button title.','rt_theme_admin'),
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][button_icon]",
								"value" => $button_icon,
								"class" => 'icon_selection', 
								"type"  => "text"),

						array(
								"name"    => __("Button Size",'rt_theme_admin'),
								"desc"      => __('Select and set the button size.','rt_theme_admin'),
								"id"      => $theTemplateID.'_'.$theGroupID."_banner_box[values][button_size]",
								"options" => array(
													"small"   => "Small",
													"medium"  => "Medium",
													"big"     => "Big", 
												),
								"default" => "small",
								"value"   => $button_size,  
								"type"    => "select"),


						array(
								"name"  => __("Button Link",'rt_theme_admin'),
								"desc"  => __('Enter a valid URL to link the button to.','rt_theme_admin'),								
								"id"    => $theTemplateID.'_'.$theGroupID."_banner_box[values][button_link]",
								"value" => $button_link,
								"class" => "button_link", 
								"type"  => "text"), 

						array(
								"name"      => __("Link Target",'rt_theme_admin'), 
								"desc"      => __('Select and set the link target.','rt_theme_admin'),
								"id"        => $theTemplateID.'_'.$theGroupID."_banner_box[values][link_target]",
								"options"   => array('_self'=>'Same Window','_blank'=>'New Window'), 
								"value"     => $link_target, 
								"type"      => "select"),

						array( 
								"type"   => "table_end"), 

					);
 
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	New Slider Box
	#
	function rt_generate_slider_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName            = __("Slider", "rt_theme_admin");
			$contet_type        = "slider_box";
			$theTemplateID      = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox           = (trim($randomClass)=="") ? false : true;
			$opacity            = 1;
			$layout             = "one passive_module";
			$position           = $isNewBox ? 'open minus' :	'plus' ;
			$data_position      = 'display: none;' ; 
			$slider_script      = isset( $options["slider_script"] ) ? $options["slider_script"] : "";
			$slider_timeout     = isset( $options["slider_timeout"] ) ? $options["slider_timeout"] : "";
			$slider_height      = isset( $options["slider_height"] ) ? $options["slider_height"] : "";  
			$flex_slider_effect = isset( $options["flex_slider_effect"] ) ? $options["flex_slider_effect"] : "";
			$nivo_slider_effect = isset( $options["nivo_slider_effect"] ) ? $options["nivo_slider_effect"] : "";  
			$slider_width       = isset( $options["slider_width"] ) ? $options["slider_width"] : "";
			$image_resize       = $isNewBox ? "" : $options["image_resize"];
			$image_crop         = $isNewBox ? "" : $options["image_crop"];

			echo '<li class="ui-state-default '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
		
								
			$form_options = array (
							
					array(
							"desc" 		=> __("This module displays a slider.",'rt_theme_admin'),	 
							"hr" 		=> "true",
							"type" 		=> "info"), 	 

					array(  "type"		=> "table_start"), 
		
					array(
							"name" 		=> __("Transition Timeout (seconds)",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slider_timeout]",
							"desc" 		=> __("Set the speed for the images cycling the slideshow.",'rt_theme_admin'),
							"hr" 		=> "true",
							"min"		=>"1",
							"max"		=>"120",
							"default"	=>"8",
							"hr"		=> true,
							"dont_save"	=> true,
							"value"		=> $slider_timeout,
							"class"		=> $randomClass,
							"type"		=> "rangeinput"),  

					array(
							"name" 		=> __("Slider Transition Effect",'rt_theme_admin'),
							"desc" 		=> __("Select and set a transition effect for this slider.",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[flex_slider_effect]", 
							"options" 	=>	array( 
												"fade"			=>	    "fade",
												"slide"			=>	    "slide", 
										 ),
							"class"		=> $randomClass,
							"value"		=> $flex_slider_effect,
							"default"	=>"slide",
							"dont_save"	=>"true",
							"type" 		=> "select"),
 
					array(
							"name" 	=> __("IMAGE RESIZE & CROP TOOLS",'rt_theme_admin'), 
							"type" 	=> "heading"), 

					array(
							"name" 		=> __("Resize Slider Images.",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[image_resize]", 
							"desc" 		=> __("Check this box to resize the slider images following the width and height values as set below.",'rt_theme_admin'),
							"class"		=> $randomClass,							
							"value"		=> $image_resize, 
							"type" 		=> "checkbox2"),

					array(
							"name" 		=> __("Crop Slider Images",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[image_crop]", 
							"desc" 		=> __("Check this box to enable the cropping feature following the width and height values as set below.",'rt_theme_admin'),
							"class"		=> $randomClass,
							"value"		=> $image_crop,
							"hr" 		=> "true",
							"type" 		=> "checkbox2"),						
					
					array(
							"name" 		=> __("Max Image Width (px)",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slider_width]",
							"desc" 		=> __("<strong>Max Image Width (px)</strong> : Set the max. width value in pixels for the slider images. You can drag the horizontal (scroll) bar to the left or right to decrease or increase the width or you can directly input the width value in the text field.<br /><br /><strong>Note</strong> : The &#39;Resize Slider Images&#39; option must be set to ON to use this option.",'rt_theme_admin'),
							"min"		=>"100",
							"max"		=>"4000",
							"default"	=>"1200", 
							"dont_save"	=> true,
							"value"		=> $slider_width,
							"class"		=> $randomClass,
							"type" 		=> "rangeinput"),

					array(
							"name"		=> __("Max Image Height (px)",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slider_height]",
							"desc" 		=> __("<strong>Max Image Height (px)</strong> : Set the max. height value in pixels for the slider images. You can drag the horizontal (scroll) bar to the left or right to decrease or increase the height or you can directly input the height value in the text field.<br /><br /><strong>Note</strong> : The &#39;Resize Slider Images&#39; option must be set to ON to use this option. ",'rt_theme_admin'),
							"min"		=>"100",
							"max"		=>"4000",
							"default"	=>"400", 
							"dont_save"	=> true,
							"value"		=> $slider_height,
							"class"		=> $randomClass,
							"type" 		=> "rangeinput"),		

					array(  "type"		=> "td_col"),

					array(
							"desc" 		=> __("CREATE SLIDES. (Press the &#39;add new slider image&#39; button to add one or more slider images)",'rt_theme_admin'),	  
							"type" 		=> "info_text_only"),

					);


			echo  $this->rt_generate_forms($form_options);
 
			//call the slides
			$options["slides"] = isset( $options["slides"] ) ? $options["slides"] : array();
			echo $this->rt_create_slides($theTemplateID,$theGroupID,$options["slides"],$randomClass);  

			$form_options = array ( array(  "type"		=> "table_end") ); 
			
			echo  $this->rt_generate_forms($form_options);
			
			echo  '</div></div></div></li>';
	}

	//create slides for the slider that embedded to the slider module
	function rt_create_slides($theTemplateID,$theGroupID,$options){

		echo '<div class="slider_creator for_slider"><ul class="slides_holder">';		 

		if ( isset( $options["slide_title"] ) ) {
			foreach ( $options["slide_title"] as $key => $value ) {

				$slide_hidden_value = ! empty( $options["slide_hidden_value"][$key] ) ? $options["slide_hidden_value"][$key] : "";
				$slide_title        = ! empty( $options["slide_title"][$key] ) ? $options["slide_title"][$key] : "";
				$slide_caption      = ! empty( $options["slide_title"][$key] ) ? $options["slide_title"][$key] : "Slide - ".intval( $key + 1 ) ;
				$slide_text         = ! empty( $options["slide_text"][$key] ) ? $options["slide_text"][$key] : "";				
				$slide_image_url    = ! empty( $options["slide_image_url"][$key] ) ? $options["slide_image_url"][$key] : "";
				$slide_link         = ! empty( $options["slide_link"][$key] ) ? $options["slide_link"][$key] : "";
				$slide_only_image   = ! empty( $options["slide_only_image"][$key] ) ? $options["slide_only_image"][$key] : "";
				$text_align         = ! empty( $options["text_align"][$key] ) ? $options["text_align"][$key] : "";
				$stretch_images     = ! empty( $options["stretch_images"][$key] ) ? $options["stretch_images"][$key] : "";


				$styling     = ! empty( $options["styling"][$key] ) ? $options["styling"][$key] : "";
				$title_color     = ! empty( $options["title_color"][$key] ) ? $options["title_color"][$key] : "";
				$title_bg_color     = ! empty( $options["title_bg_color"][$key] ) ? $options["title_bg_color"][$key] : "";
				$text_color     = ! empty( $options["text_color"][$key] ) ? $options["text_color"][$key] : "";
				$text_bg_color     = ! empty( $options["text_bg_color"][$key] ) ? $options["text_bg_color"][$key] : "";
				$title_size     = ! empty( $options["title_size"][$key] ) ? $options["title_size"][$key] : "22";
				$text_size     = ! empty( $options["text_size"][$key] ) ? $options["text_size"][$key] : "14";


				if ( $slide_hidden_value ) {
					echo '<li class="slide_options"><div class="title">'.$slide_caption.'<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

						$form_options = array (
							array(
								"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_hidden_value][]",
								"value"    	=> "1",
								"type"      => "hidden"),

							array(
								"name"      => __("Slider item Title",'rt_theme_admin'), 
								"desc"      => __('Enter a title to show within the slider item on top of the slider image or leave empty to show no title.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_title][]",
								"value"		=> $slide_title, 
								"type"      => "text"),

							array(
								"name"      => __("Slider item Textarea",'rt_theme_admin'), 
								"desc"      => __('Enter text to show in a textarea within the slider item on top of the slider image or leave empty to show no textarea with additional information.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_text][]",
								"value"		=> $slide_text, 
								"type"      => "textarea"),

							array(
								"name"      => __("Slider item Image",'rt_theme_admin'), 
								"desc"      => __('Put in a valid url to the image or press the upload button to upload and set a slider image or select an already uploaded image from the media library. <strong>Note</strong> : only image uploaded into the wordpress media library can be used. Externally linked images are not allowed because they can put your website at risk.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_image_url][]",
								"value"		=> $slide_image_url, 
								"type"      => "upload"),

							array(
								"name"      => __("Link",'rt_theme_admin'), 
								"desc"      => __('Put in a valid link to where the title (if set) and slider image should link to when clicked upon.','rt_theme_admin'),								
								"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_link][]",
								"value"		=> $slide_link, 
								"type"      => "text"), 

							array(
								"name" 		=> __("Title & Text Position",'rt_theme_admin'),
								"desc"      => __('Select and set alignment of the title and textarea.','rt_theme_admin'),								
								"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_align][]", 
								"options" 	=>	array( 
												"left"   => "Left", 								
												"right"  => "Right", 		
												"center" => "Center", 		
											 ), 
								"value"		=> $text_align,
								"default"	=>"left",
								"type" 		=> "select"),	 

							array(
								"name" 		=> __("Image Width",'rt_theme_admin'),
								"desc"      => __('Select and set the way the slider image should be displayed.','rt_theme_admin'),								
								"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][stretch_images][]", 
								"options" 	=>	array( 
												"true"   => "Display image 100% width", 								
												"false"  => "Use orginal width",  	
											 ), 
								"value"		=> $stretch_images,
								"default"	=> "true",
								"type"		=> "select"),	 



							//STYLING
							array(	 
								"type"		=> "div_start",
								"div_class"	=> "color_set options_set_holder",
							),	  				

								array(
								"name"		=> __("COLOR & FONT SIZE SETTINGS FOR THIS SLIDE",'rt_theme_admin'), 
								"type"		=> "heading"),		


								array(
								"name"		=> __("Color & Font Size",'rt_theme_admin'), 
								"id"		=>  $theTemplateID.'_'.$theGroupID."_slider_box[slides][styling][]", 
								"options"	=>  array( 
												"default"  => __("Use defaults",'rt_theme_admin'),  
												"new"      => __("Custom",'rt_theme_admin'),  
												),
								"value"		=> $styling,	
								"type"		=> "select", 
								"class"		=> "div_controller",
								),	 


								array( 
									"div_class"	=> "hidden_options_set",
									"type"		=> "div_start",

								),

									array(							
									"type"			=> "col_start",
									"holder_class"	=> "box_border paddings heading_size",
									"layout"		=> "two"
									),
											
									array(
									"name"		=> __("Title Color",'rt_theme_admin'), 
									"id"		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_color][]",  
									"value"		=> $title_color,	
									"type"		=> "colorpicker"									
									), 
									
									array(							
									"type" 		=> "col_split",
									"layout" 	=> "two"
									),

									array(
									"name"      => __("Title Background Color",'rt_theme_admin'),
									"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_bg_color][]", 
									"value"		=> $title_bg_color,	
									"type"      => "colorpicker"), 	
		 
		 							array(							
									"type" 		=> "col_end"
									),

									array(							
									"type" 			=> "col_start",
									"holder_class"  => "box_border paddings heading_size",
									"layout" 		=> "two"
									),
											
									array(
									"name"      => __("Textarea Color",'rt_theme_admin'), 
									"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_color][]",  
									"value"		=> $text_color,	
									"type"      => "colorpicker"), 
									
									array(							
									"type" 		=> "col_split",
									"layout" 	=> "two"
									),

									array(
									"name"      => __("Textarea Background Color",'rt_theme_admin'),
									"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_bg_color][]", 
									"value"		=> $text_bg_color,			
									"type"      => "colorpicker"), 	
		 
		 							array(							
									"type" 		=> "col_end"
									),				 


									array(							
									"type" 			=> "col_start",
									"holder_class"  => "box_border paddings heading_size",
									"layout" 		=> "two"
									),

									array(
									"name"      => __("Title Font Size (px)",'rt_theme_admin'), 
									"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_size][]",  
									"value"		=> $title_size,										
									"type"      => "text"
									), 
									 
									array(							
									"type" 		=> "col_split",
									"layout" 	=> "two"
									),

									array(
									"name"      => __("Text Font Size (px)",'rt_theme_admin'),
									"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_size][]", 
									"value"		=> $text_size,
									"type"      => "text"																	 
									),						

		 							array(							
									"type" 		=> "col_end"
									),																																	

								array(	 
									"type"    => "div_end"
								),				 							
			 

							array(	 
								"type"    => "div_end"
							),	


						); 

						echo  $this->rt_generate_forms($form_options);

					echo '</div></li>';	
				}
 
			}							
		}

		echo '</ul>';

		echo '<li class="slide_options new_slide"><div class="title">New Slide<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

			$form_options = array (
				array(
					"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_hidden_value][]",
					"type"      => "hidden"),

				array(
					"name"      => __("Slider item Title",'rt_theme_admin'), 
					"desc"      => __('Enter a title to show within the slider item on top of the slider image or leave empty to show no title.','rt_theme_admin'),													
					"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_title][]",
					"hr"        => "true",
					"type"      => "text"),

				array(
					"name"      => __("Slider item Textarea",'rt_theme_admin'), 
					"desc"      => __('Enter text to show in a textarea within the slider item on top of the slider image or leave empty to show no textarea with additional information.','rt_theme_admin'),												
					"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_text][]",
					"hr"        => "true",
					"type"      => "textarea"),

				array(
					"name"      => __("Slider item Image",'rt_theme_admin'), 
					"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_image_url][]",
					"desc"      => __('Put in a valid url to the image or press the upload button to upload and set a slider image or select an already uploaded image from the media library. <strong>Note</strong> : only image uploaded into the wordpress media library can be used. Externally linked images are not allowed because they can put your website at risk.','rt_theme_admin'),								
					"hr"        => "true",
					"value"		=> "",
					"type"      => "upload"),

				array(
					"name"      => __("Link",'rt_theme_admin'), 
					"desc"      => __('Put in a valid link to where the title (if set) and slider image should link to when clicked upon.','rt_theme_admin'),													
					"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][slide_link][]",
					"hr"        => "true",
					"type"      => "text"),

				array(
					"name" 		=> __("Title & Text Position",'rt_theme_admin'),
					"desc"      => __('Select and set alignment of the title and textarea.','rt_theme_admin'),								
					"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_align][]", 
					"options" 	=>	array( 
									"left"   => "Left", 								
									"right"  => "Right", 		
									"center" => "Center", 		
								 ), 
					"value"		=> "",
					"default"	=>"left",
					"type" 		=> "select"),		 
 
				array(
					"name" 		=> __("Image Width",'rt_theme_admin'),
					"desc"      => __('Select and set the way the slider image should be displayed.','rt_theme_admin'),
					"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][stretch_images][]", 
					"options" 	=>	array( 
									"true"   => "Display image 100% width", 								
									"false"  => "Use orginal width",  	
								 ), 
					"default"	=> "true",
					"type" 		=> "select"),	

				//STYLING
				array(	 
					"type"    => "div_start",
					"div_class"   => "color_set options_set_holder",
				),	  				

					array(
					"name" 		=> __("COLOR SETTINGS FOR THE DEFAULT CONTENT AREA",'rt_theme_admin'), 
					"type" 		=> "heading"),		


					array(
					"name"      => __("Color Style",'rt_theme_admin'), 
					"id"        =>  $theTemplateID.'_'.$theGroupID."_slider_box[slides][styling][]", 
					"options"   =>  array( 
									"default"  => __("Use defaults",'rt_theme_admin'),  
									"new"      => __("Custom",'rt_theme_admin'),  
									), 
					"type"      => "select", 
					"class"     => "div_controller",
					),	 


					array( 
						"div_class"   => "hidden_options_set",
						"type"    => "div_start",

					),

						array(							
						"type" 			=> "col_start",
						"holder_class" 	=> "box_border paddings heading_size",
						"layout" 		=> "two"
						),
								
						array(
						"name"      => __("Title Color",'rt_theme_admin'), 
						"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_color][]",  
						"type"      => "colorpicker",
						"class"		=> "hidden_slide_item"
						), 
						
						array(							
						"type" 		=> "col_split",
						"layout" 	=> "two"
						),

						array(
						"name"      => __("Title Background Color",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_bg_color][]", 
						"type"      => "colorpicker",
						"class"		=> "hidden_slide_item"
						),  	

							array(							
						"type" 		=> "col_end"
						),

						array(							
						"type" 			=> "col_start",
						"holder_class"  => "box_border paddings heading_size",
						"layout" 		=> "two"
						),
								
						array(
						"name"      => __("Textarea Color",'rt_theme_admin'), 
						"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_color][]",  
						"type"      => "colorpicker",
						"class"		=> "hidden_slide_item"
						), 
						
						array(							
						"type" 		=> "col_split",
						"layout" 	=> "two"
						),

						array(
						"name"      => __("Textarea Background Color",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_bg_color][]", 
						"type"      => "colorpicker",
						"class"		=> "hidden_slide_item"
						), 

						array(							
						"type" 		=> "col_end"
						),				 
								
						array(							
						"type" 			=> "col_start",
						"holder_class"  => "box_border paddings heading_size",
						"layout" 		=> "two"
						),
								

						array(
						"name"      => __("Title Font Size (px)",'rt_theme_admin'), 
						"id"        => $theTemplateID.'_'.$theGroupID."_slider_box[slides][title_size][]",  
						"type"      => "text"
						), 
						 
						array(							
						"type" 		=> "col_split",
						"layout" 	=> "two"
						),

						array(
						"name"      => __("Text Font Size (px)",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_slider_box[slides][text_size][]", 
						"type"      => "text"																	 
						),						

							array(							
						"type" 		=> "col_end"
						),																																	

					array(	 
						"type"    => "div_end"
					),				 							
 

				array(	 
					"type"    => "div_end"
				),	
							
			); 

			echo  $this->rt_generate_forms($form_options);

		echo '</div></li>'; 
		echo '<button type="button" class="template_button green rt_add_new_slide icon-plus-squared-1">'.__('add new slider image','rt_theme_admin') .' </button>';  
		echo '</div>';
	}

	#
	#	Tabs Box
	#
	function rt_generate_tabs_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Tabular Content", "rt_theme_admin");
			$contet_type   = "tabs_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module";
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;
 

 			$tabs_style = isset($options["tabs_style"]) ? $options["tabs_style"] : "";


			echo '<li class="ui-state-default tabs_box '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

								
			$form_options = array (
  
				array(
						"desc" 		=> __("This module is to display entered content in tabs.",'rt_theme_admin'),	 
						"hr" 		=> "true",
						"type" 		=> "info"), 	 

				array(
						"name"		=> __("Select Tabs Style",'rt_theme_admin'),
						"desc" 		=> __("Select and set the tabs layout (horizontal or vertical).",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_tabs_box[tabs_style]", 
						"options" 	=>	array( 
											"horizontal" => __("Horizontal Tabs","rt_theme_admin"),
											"horizontal2" => __("Horizontal Tabs (Style 2)","rt_theme_admin"),
											"horizontal3" => __("Horizontal Tabs (Style 3)","rt_theme_admin"),
											"vertical" => __("Vertical Tabs","rt_theme_admin")
										), 
						"value"		=> $tabs_style,
						"hr" 		=> "true",
						"dont_save"	=> true,
						"type"		=> "select"),  
 

					array(
							"desc" 		=> __("CREATE TABS. Press the &#39;add new tab&#39; button to add one or more tabs.",'rt_theme_admin'),	  
							"type" 		=> "info_text_only"), 
			);


			echo  $this->rt_generate_forms($form_options);
			 
			//call the tabs
			$options["tab_contents"] = isset( $options["tab_contents"] ) ? $options["tab_contents"] : array();
			echo $this->rt_create_tabs($theTemplateID,$theGroupID,$options["tab_contents"],$randomClass);   

			echo  '</div></div></div></li>';
 
	}

	//create slides for the slider that embedded to the slider module
	function rt_create_tabs($theTemplateID,$theGroupID,$options){

		echo '<div class="slider_creator for_tabs"><ul class="slides_holder">';		  

		if ( isset( $options["caption"] ) ) {
			foreach ( $options["caption"] as $key => $value ) {

				$caption = ! empty( $options["caption"][$key] ) ? $options["caption"][$key] : "";
				$text    = ! empty( $options["text"][$key] ) ? $options["text"][$key] : "";		
				$icon    = ! empty( $options["icon"][$key] ) ? $options["icon"][$key] : "";				 

				if ( $caption ) {
					echo '<li class="slide_options"><div class="title">'.stripslashes($caption).'<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

						$form_options = array (

							array("type"    => "table_start"),

							array(
								"name"      => __("Caption",'rt_theme_admin'), 
								"desc"      => __('Enter a tab caption title.','rt_theme_admin'),
								"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][caption][]", 
								"value"     => $caption, 
								"type"      => "text"),  

							array("type"   => "td_col"),

							array(
								"name"      => __("Icon",'rt_theme_admin'), 
								"desc"      => __('Select and set a icon to precede the caption (optional).','rt_theme_admin'),
								"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][icon][]", 
								"value"     => $icon,
								"class"     => 'icon_selection', 
								"type"      => "text"), 

							array("type"    => "table_end"),

							array( 
									"type" => "col_start",
									"layout" => "one",
									"holder_class" => "labels_block box_border paddings",
							),

							array(
								"name"      => __("Text",'rt_theme_admin'), 
								"desc"      => __('Enter the content to be displayed within the tab. The content becomes visible when the tab is active.','rt_theme_admin'),
								"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][text][]",								
								"css_id"    => $theTemplateID.'_'.$theGroupID."_tabs_box".$key,
								"value"     => $text, 
								"type"      => "textarea_tinyMCE"), 

							array( 
									"type" => "col_end"
							),	

						); 

						echo  $this->rt_generate_forms($form_options);

					echo '</div></li>';	
				}
 
			}							
		}

		echo '<li class="slide_options new_slide"><div class="title">New Tab<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

			$form_options = array (

				array("type"    => "table_start"),

				array(
					"name"      => __("Caption",'rt_theme_admin'), 
					"desc"      => __('Enter a tab caption title.','rt_theme_admin'),					
					"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][caption][]",
					"hr"        => "true",
					"type"      => "text"),

				array("type"    => "td_col"),

				array(
					"name"      => __("Icon",'rt_theme_admin'), 
					"desc"      => __('Select and set a icon to precede the caption (optional).','rt_theme_admin'),					
					"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][icon][]",  
					"class"     => 'icon_selection',
					"hr"        => "true",
					"type"      => "text"),		

				array("type"    => "table_end"), 

				array( 
						"type" => "col_start",
						"layout" => "one",
						"holder_class" => "labels_block box_border paddings",
				),

				array(
					"name"      => __("Text",'rt_theme_admin'),
					"desc"      => __('Enter the content to be displayed within the tab. The content becomes visible when the tab is active.','rt_theme_admin'),					
					"id"        => $theTemplateID.'_'.$theGroupID."_tabs_box[tab_contents][text][]",
					"css_id"    => $theTemplateID.'_'.$theGroupID."_tabs_box_new", 
					"type"      => "textarea_tinyMCE"),  		

				array( 
						"type" => "col_end"
				),	
							
			); 

			echo  $this->rt_generate_forms($form_options);

		echo '</div></li>';   
		echo '</ul>'; 
		echo '<button type="button" class="template_button green rt_add_new_slide icon-plus-squared-1">'.__('add new tab','rt_theme_admin') .' </button>';  		
		echo '</div>';

	}

	#
	#	Accordion Box
	#
	function rt_generate_accordion_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Accordion Content", "rt_theme_admin");
			$contet_type   = "accordion_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module";
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;
 

 			$accordion_style = isset($options["accordion_style"]) ? $options["accordion_style"] : ""; 
 			$first_one_open = isset($options["first_one_open"]) ? $options["first_one_open"] : ""; 

			echo '<li class="ui-state-default '.$layout.' '.$randomClass.' accordion_box" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

								
			$form_options = array (
  
				array(
						"desc" 		=> __("This module displays a accordion with content.",'rt_theme_admin'),	 
						"hr" 		=> "true",
						"type" 		=> "info"), 	 

				array(
						"name"		=> __("Select Accordion Style",'rt_theme_admin'), 
						"desc"      => __('Select and set the accordion style. <br /><br />&#39;Numbered&#39; : the caption is preceded by a number,<br />&#39;With icons&#39; :  the caption is preceded by a icon, <br />&#39;Captions Only&#39; : the caption without icon or number is displayed.','rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_style]", 
						"options" 	=>	array( 
											"numbered" => "Numbered",
											"icons" => "With Icons",
											"only_captions" => "Captions Only"
									), 
						"value"		=> $accordion_style,
						"hr" 		=> "true",
						"dont_save"	=> true,
						"type"		=> "select"),  
 


					array(
							"name" 	=> __("First One Visible",'rt_theme_admin'),
							"check_desc"  => __("Make the first accordion content visible when the page loaded.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_accordion_box[first_one_open]",
							"type" 	=> "checkbox",
							"class"	=> $randomClass,
							"value"	=> $first_one_open,  
							"default" => "",
							"std" 	=> "false",
							"hr" 	=> "true"),

					array(
						"desc" 		=> __("CREATE CONTENTS",'rt_theme_admin'),	  
						"type" 		=> "info_text_only"), 
			);


			echo  $this->rt_generate_forms($form_options);
			 
			//call the accordions
			$options["accordion_contents"] = isset( $options["accordion_contents"] ) ? $options["accordion_contents"] : array();
			echo $this->rt_create_accordions($theTemplateID,$theGroupID,$options["accordion_contents"],$randomClass);  
			echo  '</div></div></div></li>';
	}

	//creates accordion contents
	function rt_create_accordions($theTemplateID,$theGroupID,$options){

		echo '<div class="slider_creator for_accordions"><ul class="slides_holder">';		 


		if ( isset( $options["caption"] ) ) {
			foreach ( $options["caption"] as $key => $value ) {

				$caption = ! empty( $options["caption"][$key] ) ? $options["caption"][$key] : "";
				$text    = ! empty( $options["text"][$key] ) ? $options["text"][$key] : "";		
				$icon    = ! empty( $options["icon"][$key] ) ? $options["icon"][$key] : "";				 

				if ( $caption ) {
					echo '<li class="slide_options"><div class="title">'.stripslashes($caption).'<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

						$form_options = array (

							array("type"    => "table_start"),

							array(
								"name"      => __("Caption",'rt_theme_admin'), 
								"desc"      => __('Enter the accordion caption title.','rt_theme_admin'),													
								"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][caption][]", 
								"value"     => $caption, 
								"type"      => "text"),  

							array("type"   => "td_col"),

							array(
								"name"      => __("Icon",'rt_theme_admin'),
								"desc"      => __('Select and set a icon to precede the caption (optional).','rt_theme_admin'),													
								"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][icon][]", 
								"value"     => $icon,
								"class"     => 'icon_selection', 
								"type"      => "text"), 

							array("type"    => "table_end"),

							array( 
									"type" => "col_start",
									"layout" => "one",
									"holder_class" => "labels_block box_border paddings",
							),

							array(
								"name"      => __("Text",'rt_theme_admin'), 
								"desc"      => __('Enter the content to be displayed within the accordion panel. The content becomes visible when the accordion panel is active.','rt_theme_admin'),													
								"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][text][]",								
								"css_id"    => $theTemplateID.'_'.$theGroupID."_accordion_box".$key,
								"value"     => $text, 
								"type"      => "textarea_tinyMCE"), 

							array( 
									"type" => "col_end"
							)							
						); 

						echo  $this->rt_generate_forms($form_options);

					echo '</div></li>';	
				}
 
			}							
		}

		echo '<li class="slide_options new_slide"><div class="title">New Content<span class="s_edit"></span><span class="s_delete"></span></div><div class="options">';

			$form_options = array (

				array("type"		=> "table_start"),

				array(
					"name"      => __("Caption",'rt_theme_admin'), 
					"desc"      => __('Enter the accordion caption title.','rt_theme_admin'),																		
					"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][caption][]",
					"hr"        => "true",
					"type"      => "text"),

				array("type"   => "td_col"),

				array(
					"name"      => __("Icon",'rt_theme_admin'), 
					"desc"      => __('Select and set a icon to precede the caption (optional).','rt_theme_admin'),																		
					"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][icon][]",  
					"class"		=> 'icon_selection',
					"hr"        => "true",
					"type"      => "text"),		

				array("type"    => "table_end"),

				array( 
					"type"         => "col_start",
					"layout"       => "one",
					"holder_class" => "labels_block box_border paddings",
				),
				array(
					"name"      => __("Text",'rt_theme_admin'), 
					"desc"      => __('Enter the content to be displayed within the accordion panel. The content becomes visible when the accordion panel is active.','rt_theme_admin'),																		
					"id"        => $theTemplateID.'_'.$theGroupID."_accordion_box[accordion_contents][text][]",
					"css_id"    => $theTemplateID.'_'.$theGroupID."_accordion_box_new", 
					"type"      => "textarea_tinyMCE"),  		

				array( 
						"type" => "col_end"
				),					
			); 

			echo  $this->rt_generate_forms($form_options);

		echo '</div></li>';   
		echo '</ul>';  
		echo '<button type="button" class="template_button green rt_add_new_slide icon-plus-squared-1">'.__('add new content','rt_theme_admin') .' </button>';  				
		echo '</div>';
	}

	#
	#	Horizontal Line Box
	#
	function rt_generate_horizontal_line($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Horizontal Line", "rt_theme_admin");
			$contet_type   = "horizontal_line";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module";
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ; 
 			$style         = isset($options["style"]) ? $options["style"] : ""; 
 			$margin_top    = isset($options["margin_top"]) ? $options["margin_top"] : ""; 
 			$margin_bottom = isset($options["margin_bottom"]) ? $options["margin_bottom"] : ""; 
			 
			 
			echo '<li class="ui-state-default '.$layout.' '.$randomClass.' tabs_box" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
 								
			$form_options = array (
  
				array(
						"desc" 		=> __("This module displays an horizontal line",'rt_theme_admin'),	 
						"hr" 		=> "true",
						"type" 		=> "info"), 	 

				array(
						"name"		=> __("Select a style",'rt_theme_admin'),
						"desc" 		=> __("Select one of the three available styles for the horizontal line",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_horizontal_line[style]", 
						"options" 	=>	array(  
											"1" => "Style 1 - Double Line With Circle",
											"2" => "Style 2 - Double Line With Dot",
											"3" => "Style 3 - Double Line With Waves",
											"4" => "Style 4 - Double Line Only",
											"5" => "Style 5 - Classic Single Line",
											"6" => "Style 6 - Half Colored Line With Down Arrow ",
											"7" => "Style 7 - Line With White Down Arrow ",
											"8" => "Style 8 - Colored Line With Down Arrow",
									), 
						"value"		=> $style,
						"hr" 		=> "true",
						"dont_save"	=> true,
						"type"		=> "select"),   	

				array(
						"name"		=> __("Margin Top",'rt_theme_admin'),
						"desc" 		=> __("Select top margin values for the HR element",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_horizontal_line[margin_top]", 
						"options" 	=>	array(  
											"0" => "No Margin",
											"5" => "5px",
											"10" => "10px",
											"15" => "15px",
											"20" => "20px",
											"30" => "30px",
											"40" => "40px",
											"50" => "50px",
											"60" => "60px",
											"70" => "70px",
											"80" => "80px",
									), 
						"value"		=> $margin_top,
						"hr" 		=> "true",
						"dont_save"	=> true,
						"type"		=> "select"),   		


				array(
						"name"		=> __("Margin Bottom",'rt_theme_admin'),
						"desc" 		=> __("Select bottom margin values for the HR element",'rt_theme_admin'),
						"id" 		=> $theTemplateID.'_'.$theGroupID."_horizontal_line[margin_bottom]", 
						"options" 	=>	array(  
											"0" => "No Margin",
											"5" => "5px",
											"10" => "10px",
											"15" => "15px",
											"20" => "20px",
											"30" => "30px",
											"40" => "40px",
											"50" => "50px",
											"60" => "60px",
											"70" => "70px",
											"80" => "80px",
									), 
						"value"		=> $margin_bottom,
						"hr" 		=> "true",
						"dont_save"	=> true,
						"type"		=> "select"),   												
			); 

			echo  $this->rt_generate_forms($form_options);  
			echo  '</div></div></div></li>';
	}

	#
	#	Layer Slider Box
	#
	function rt_generate_layerslider_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Layer Slider", "rt_theme_admin");
			$contet_type   = "layerslider_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;
			$slider_id     = $isNewBox ? '' : $options['slider_id'];


			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
								
			$options = array (
 
					array( 
							"value"		=> "one", 						 
							"id" 		=> $theTemplateID.'_'.$theGroupID."_layerslider_box[layout]",
							"type" 		=> "hidden", 
					),
							
					array(
							"desc" 		=> __("This module displays a slider of the Layer Slider plugin.",'rt_theme_admin'),	 
							"hr" 		=> "true",
							"type" 		=> "info"), 							
		 

					array(
							   "name" => __("Select a slider",'rt_theme_admin'), 
							   "desc" => __('Select a slider to display.','rt_theme_admin'),
							   "id" => $theTemplateID.'_'.$theGroupID."_layerslider_box[slider_id]",
							   "options" =>	rt_layer_slider_list(),
							   "value"=>$slider_id, 
							   "hr" => "true",
							   "type" => "select"),		 
					);
					
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Revolution Slider Box
	#
	function rt_generate_revslider_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Revolution Slider", "rt_theme_admin");
			$contet_type   = "revslider_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ;
			$slider_id     = $isNewBox ? '' : $options['slider_id'];


			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
								
			$options = array (
 
					array( 
							"value"		=> "one", 						 
							"id" 		=> $theTemplateID.'_'.$theGroupID."_revslider_box[layout]",
							"type" 		=> "hidden", 
					),
							
					array(
							"desc" 		=> __("This module displays a slider of the Revolution Slider plugin.",'rt_theme_admin'),	 
							"hr" 		=> "true",
							"type" 		=> "info"), 	

					array(
							   "name" => __("Select a slider",'rt_theme_admin'), 
							   "desc" => __('Select a slider to display.','rt_theme_admin'),
							   "id" => $theTemplateID.'_'.$theGroupID."_revslider_box[slider_id]",
							   "options" =>	rt_rev_slider_list(),
							   "value"=>$slider_id, 
							   "hr" => "true",
							   "type" => "select"),		 
					);
					
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}


	#
	#	Content Box with Image
	#
	function rt_generate_new_content_box($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName        = __("Content Box With Image", "rt_theme_admin");
			$contet_type    = "new_content_box";
			$theTemplateID  = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox       = (trim($randomClass)=="") ? false : true; 
			$opacity        = 1;
			$layout         = "one passive_module" ;
			$position       = $isNewBox ? 'open minus' :	'plus' ;
			$data_position  = 'display: none;' ;	 
			$title          = isset($options["title"]) ? $options["title"] : "";
			$title_position = isset($options["title"]) ? $options["title_position"] : "";
			$text           = isset($options["text"] ) ? $options["text"] : "";
			$featured_image = isset($options["featured_image"] ) ? $options["featured_image"] : ""; 
			$icon           = isset($options["icon"]) ? $options["icon"] : ""; 
			$icon_style     = isset($options["icon_style"]) ? $options["icon_style"] : ""; 
			$text_position  = isset($options["text_position"]) ? $options["text_position"] : "";
			$link           = isset($options["link"]) ? $options["link"] : "";
			$link_text      = isset($options["link_text"]) ? $options["link_text"] : "";
			$link_target    = isset($options["link_target"]) ? $options["link_target"] : "";
			$image_style    = isset($options["image_style"]) ? $options["image_style"] : "";


			$featured_image_visibility = isset($icon_style) && intval($icon_style) > 2 ? "featured_image_visibility" : "featured_image_visibility active";
 
			echo '<li class="ui-state-default for_content_boxes '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
 			

			$options = array (

					array(
							"desc" => __("This module allows to create a styled content box with a big icon or featured image.",'rt_theme_admin'),
							"hr"   => "true",
							"type" => "info"), 

					array(
							"name"		=> __("Title",'rt_theme_admin'),						
							"desc"      => __('Enter a title to show in the content box area.','rt_theme_admin'),							
							"id" 		=> $theTemplateID.'_'.$theGroupID."_new_content_box[title]", 
							"value"		=> $title, 
							"type"		=> "text"), 

					array( 		
							"name"		=> __("Content Box Textarea",'rt_theme_admin'),					
							"id"          => $theTemplateID.'_'.$theGroupID."_new_content_box[text]", 
							"desc"      => __('Enter any content (shortcode, text, or valid html by using the html button) in the editor area.','rt_theme_admin'),
							"value"       => $text, 
							"table_class" => "fulltable",
							"type"        => "textarea_tinyMCE"),   

 
					array(  "type" => "table_start"),


					array(
							"name"      => __("POSITIONS",'rt_theme_admin'), 
							"type"      => "heading"), 
 
					array(
							"name"      => __("Title Position",'rt_theme_admin'),
							"desc"      => __("Select and set the title position.",'rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box[title_position]", 
							"options"   => array('embedded'=>'Embedded to the featured image','before'=>'Before Featured Image','after'=>'After Featured Image'),					
							"value"     => $title_position,
							"default"   => "embedded", 
							"type"      => "select"), 

					array(
							"name"      => __("Content Alignment",'rt_theme_admin'), 
							"desc"      => __('Select and set aligment of all content of the content box module.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box[text_position]", 
							"options"   => array('1'=>'Left Aligned','2'=>'Centered'),	 
							"value"     => $text_position,  
							"type"      => "select"),


					array(
							"name"      => __("LINK",'rt_theme_admin'), 
							"type"      => "heading"), 


					array(
							"name"		=> __("Link",'rt_theme_admin'),						
							"desc"      => __('Put in a valid link to where the linktext supplied in the next field should link to when clicked upon. <strong>Note</strong> : The link is shown at the bottom of the content box.','rt_theme_admin'),																				
							"id" 		=> $theTemplateID.'_'.$theGroupID."_new_content_box[link]", 
							"value"		=> $link, 
							"type"		=> "text"), 					

					array(
							"name"		=> __("Link Text",'rt_theme_admin'),						
							"desc"      => __('Provide a text for the link button.','rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_new_content_box[link_text]", 
							"value"		=> $link_text, 
							"type"		=> "text"), 

					array(
							"name"      => __("Link Target",'rt_theme_admin'),
							"desc"      => __('Select and set the link target.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box[link_target]", 
							"options"   => array('_self'=>'Same Window','_blank'=>'New Window'),					
							"hr"        => true,
							"value"     => $link_target, 
							"type"      => "select"),

			
					array(
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box_header_div_end",
							"type"      => "div_end" 
					), 

					array(  "type"		=> "td_col"),

 
 					array(
							"name"      => __("ICON STYLE",'rt_theme_admin'), 
							"type"      => "heading"), 

					array(
							"name"      => __("Select Icon Style",'rt_theme_admin'), 
							"desc"      => __('Select and set the Icon style. <strong>Note</strong> : To be able to add a featured image select one of the two available &#39;small icon&#39; options.','rt_theme_admin'),							
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box[icon_style]", 
							"options"   => array('0'=>'No Icon','1'=>'Small Icon','2'=>'Small icon with squared background'),					
							"hr"        => true,
							"value"     => $icon_style,
							"type"      => "select"),   

					array(
							"name"		=> __("Icon",'rt_theme_admin'),	
							"desc"      => __('Select and set the icon to display within the content box.','rt_theme_admin'),							
							"id" 		=> $theTemplateID.'_'.$theGroupID."_new_content_box[icon]", 
							"desc"		=> __('Click into the text field to select an icon or type an icon name.','rt_theme_admin'),
							"value"		=> $icon,
							"class"		=> 'icon_selection', 
							"type"		=> "text"),   

 					array(
							"name"      => __("FEATURED IMAGE",'rt_theme_admin'), 
							"type"      => "heading"), 

					array(
							"name"      => __("Featured Image Style",'rt_theme_admin'), 
							"desc"      => __('Select and set the Icon style','rt_theme_admin'),							
							"id"        => $theTemplateID.'_'.$theGroupID."_new_content_box[image_style]", 
							"options"   => array('0'=>'Square standart','1'=>'Rounded with pin'),					
							"hr"        => true,
							"value"     => $image_style,
							"class"     => "select_featured_image_style",
							"type"      => "select"),   

					array(
							"name"		=> __("Featured Image",'rt_theme_admin'),
							"desc"      => __('Please add a image by the use of the upload button or insert a valid url to a image to use as a featured image. <strong>Note</strong> : Externally linked images are not allowed because they can put your website at risk.','rt_theme_admin'),
							"id"		=> $theTemplateID.'_'.$theGroupID."_new_content_box[featured_image]",   
							"type"		=> "upload",
							"value"		=> $featured_image),   

					array(  "type"		=> "table_end"),
 

					);

			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Content Box with Icon
	#	
	function rt_generate_content_icon_box($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName        = __("Content Box With Icon", "rt_theme_admin");
			$contet_type    = "content_icon_box";
			$theTemplateID  = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox       = (trim($randomClass)=="") ? false : true; 
			$opacity        = 1;
			$layout         = "one passive_module" ;
			$position       = $isNewBox ? 'open minus' :	'plus' ;
			$data_position  = 'display: none;' ;	 
			$title          = isset($options["title"]) ? $options["title"] : "";
			$title_position = isset($options["title"]) ? $options["title_position"] : "";
			$text           = isset($options["text"] ) ? $options["text"] : "";
			$icon           = isset($options["icon"]) ? $options["icon"] : ""; 
			$icon_style     = isset($options["icon_style"]) ? $options["icon_style"] : ""; 
			$text_position  = isset($options["text_position"]) ? $options["text_position"] : "";
			$link           = isset($options["link"]) ? $options["link"] : "";
			$link_text      = isset($options["link_text"]) ? $options["link_text"] : "";
			$link_target    = isset($options["link_target"]) ? $options["link_target"] : "";

			$featured_image_visibility = isset($icon_style) && intval($icon_style) > 2 ? "featured_image_visibility" : "featured_image_visibility active";
 
			echo '<li class="ui-state-default for_content_boxes '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
 			

			$options = array (

					array(
							"desc" => __("This module allows to create a styled content box with a big icon or featured image.",'rt_theme_admin'),
							"hr"   => "true",
							"type" => "info"), 

					array(
							"name"		=> __("Title",'rt_theme_admin'),						
							"desc"      => __('Enter a title to show in the content box area.','rt_theme_admin'),							
							"id" 		=> $theTemplateID.'_'.$theGroupID."_content_icon_box[title]", 
							"value"		=> $title, 
							"type"		=> "text"), 

					array( 		
							"name"		=> __("Content Box Textarea",'rt_theme_admin'),					
							"id"          => $theTemplateID.'_'.$theGroupID."_content_icon_box[text]", 
							"desc"      => __('Enter any content (shortcode, text, or valid html by using the html button) in the editor area.','rt_theme_admin'),
							"value"       => $text, 
							"table_class" => "fulltable",
							"type"        => "textarea_tinyMCE"),   

 
					array(  "type" => "table_start"),


					array(
							"name"      => __("POSITIONS",'rt_theme_admin'), 
							"type"      => "heading"), 


					array(
							"name"      => __("Title Position",'rt_theme_admin'),
							"desc"      => __("Select and set the title position.",'rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_content_icon_box[title_position]", 
							"options"   => array('embedded'=>'Right side of the icon','before'=>'Before the icon','after'=>'After the icon '),					
							"value"     => $title_position,
							"default"   => "embedded", 
							"type"      => "select"), 

					array(
							"name"      => __("Content Alignment",'rt_theme_admin'), 
							"desc"      => __('Select and set aligment of all content of the content box module.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_content_icon_box[text_position]", 
							"options"   => array('1'=>'Left Aligned','2'=>'Centered'),	 
							"value"     => $text_position,  
							"type"      => "select"),


					array(
							"name"      => __("LINK",'rt_theme_admin'), 
							"type"      => "heading"), 


					array(
							"name"		=> __("Link",'rt_theme_admin'),						
							"desc"      => __('Put in a valid link to where the linktext supplied in the next field should link to when clicked upon. <strong>Note</strong> : The link is shown at the bottom of the content box.','rt_theme_admin'),																				
							"id" 		=> $theTemplateID.'_'.$theGroupID."_content_icon_box[link]", 
							"value"		=> $link, 
							"type"		=> "text"), 					

					array(
							"name"		=> __("Link Text",'rt_theme_admin'),						
							"desc"      => __('Provide a text for the link button.','rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_content_icon_box[link_text]", 
							"value"		=> $link_text, 
							"type"		=> "text"), 

					array(
							"name"      => __("Link Target",'rt_theme_admin'),
							"desc"      => __('Select and set the link target.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_content_icon_box[link_target]", 
							"options"   => array('_self'=>'Same Window','_blank'=>'New Window'),					
							"hr"        => true,
							"value"     => $link_target, 
							"type"      => "select"),
 

					array(  "type"		=> "td_col"),

 
 					array(
							"name"      => __("ICON STYLE",'rt_theme_admin'), 
							"type"      => "heading"), 

					array(
							"name"      => __("Select Icon Style",'rt_theme_admin'), 
							"desc"      => __('Select and set the Icon style','rt_theme_admin'),							
							"id"        => $theTemplateID.'_'.$theGroupID."_content_icon_box[icon_style]", 
							"options"   => array('0'=>'No Icon','1'=>'Small Icon','2'=>'Small icon with squared background','3'=>'Big Icon','4'=>'Big Icon with squared background', '5'=>'Big Icon with rounded background', '6'=>'Big Icon with rounded border', '7'=>'Big Icon with rounded border and pin'),					
							"hr"        => true,
							"value"     => $icon_style,
							"class"     => "select_content_box_style",
							"type"      => "select"),   

					array(
							"name"		=> __("Icon",'rt_theme_admin'),	
							"desc"      => __('Select and set the icon to display within the content box.','rt_theme_admin'),							
							"id" 		=> $theTemplateID.'_'.$theGroupID."_content_icon_box[icon]", 
							"desc"		=> __('Click into the text field to select an icon or type an icon name.','rt_theme_admin'),
							"value"		=> $icon,
							"class"		=> 'icon_selection', 
							"type"		=> "text"),  

					array(  "type"		=> "table_end"),

					);

			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Text Box
	#
	function rt_generate_text_box($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName        = __("Text Box", "rt_theme_admin");
			$contet_type    = "text_box";
			$theTemplateID  = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox       = (trim($randomClass)=="") ? false : true; 
			$opacity        = 1;
			$layout         = "one passive_module" ;
			$position       = $isNewBox ? 'open minus' : 'plus' ;
			$data_position  = 'display: none;' ;	 
			$values     	= isset($options["values"]) ? $options["values"] : array();

			$text = $font_size = $font_color = $heading_color = $font_family_text = $font_family_heading = "";
			extract( $values );
 
			echo '<li class="ui-state-default for_content_boxes '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';
 			

			//create font size array
			$font_sizes = array();
			for ($i=11; $i < 51 ; $i++) { 
				$font_sizes[$i] = $i."px";
			}

			$options = array (

					array(
							"desc" => __("This module adds a box with any content, at the location where the box is inserted, into the template. <strong>Note</strong> : Any valid html, shortcode or text content is allowed by using the 'HTML' button.",'rt_theme_admin'),
							"hr"   => "true",
							"type" => "info"),  

					array( 
							"type" 		   => "col_start",
							"layout" 	   => "one",
							"holder_class" => "labels_block box_border paddings",
					),

					array( 		
							"name"		  => __("Content Box Textarea",'rt_theme_admin'),					
							"id"          => $theTemplateID.'_'.$theGroupID."_text_box[values][text]", 
							"desc"		  => __('Enter any content (shortcode, text, or valid html by using the html button) in the editor area.','rt_theme_admin'),
							"value"       => $text, 
							"table_class" => "fulltable",
							"hr"		  => "true",
							"type"		  => "textarea_tinyMCE"),    


					array( 
							"type"		=> "col_end"
					),	

					array(  
							"type"		=> "table_start",  
					),

					array(
							"name"      => __("Color (Text)",'rt_theme_admin'),
							"desc" 		=> __('Click within the color field or on the circular element of the color field to open up the colorpicker. In the colorpicker select a color by dragging the circular object within the colorgrid. You can also insert manually a valid html color code. If you would like to turn back to the default color, just delete the value and make sure to save the settings. Leave blank to use the default color.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_text_box[values][font_color]",    
							"dont_save" => "true",
							"hr" 		=> "true",  
							"value"		=> $font_color,
							"type"      => "colorpicker"),	

					array(
							"name"      => __("Color (Headings)",'rt_theme_admin'),
							"desc" 		=> __('Click within the color field or on the circular element of the color field to open up the colorpicker. In the colorpicker select a color by dragging the circular object within the colorgrid. You can also insert manually a valid html color code. If you would like to turn back to the default color, just delete the value and make sure to save the settings. Leave blank to use the default color.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_text_box[values][heading_color]",    
							"dont_save" => "true",
							"hr" 		=> "true",  
							"value"		=> $heading_color,
							"type"      => "colorpicker"),	

					array(
							"name" 		=> __("Font Size (Text)",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_text_box[values][font_size]",
							"options" 	=> $font_sizes,
							"select" 	=> __('Default','rt_theme_admin'),
							"default"	=> "",
							"value"		=> $font_size,  
							"type" 		=> "select"),

					array(  
							"type"    		=> "td_col",
					),


					array(
							"name" 		=> __("Font (Headings)",'rt_theme_admin'),
							"desc" 		=> __("Select a font for the heading elements (h-tags).",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_text_box[values][font_family_heading]",
							"options" 	=> $this->rt_font_list,
							"font-demo" => "true", 
							"class" 	=> "fontlist",
							"select"	=>__("Default Font",'rt_theme_admin'),
							"hr" 		=> "true",  
							"default"	=> "",
							"value"		=> $font_family_heading,  
							"type" 		=> "select"),


					array(
							"name" 		=> __("Font (Text)",'rt_theme_admin'),
							"desc" 		=> __("Select a font for the text",'rt_theme_admin'),
							"id" 		=> $theTemplateID.'_'.$theGroupID."_text_box[values][font_family_text]",
							"options" 	=> $this->rt_font_list,
							"font-demo" => "true", 
							"class" 	=> "fontlist",
							"select"	=>__("Default Font",'rt_theme_admin'),
							"default"	=> "",
							"value"		=> $font_family_text,  
							"type" 		=> "select"),			

					array(  
							"type"    		=> "table_end",
					),

					);



			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Default Contet Box
	#
	function rt_generate_default_content($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Default Page Content", "rt_theme_admin");
			$contet_type   = "default_content";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);			
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus':'plus';
			$data_position = 'display: none;';	  
		
			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
 
					
					array(
							"desc" => __("This module displays the default page or post content at the location within the template it is inserted. If this module is not used within a column the default content will be visible in full width.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),
 
					array( 
							"value"	=> "1", 
							"id" 	=> $theTemplateID.'_'.$theGroupID."_default_content[hidden]",
							"type" 	=> "hidden", 
					),
					  				
					);
					
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}
	
	#
	#	Blog Box
	#
	function rt_generate_blog_box($theGroupID,$theTemplateID,$options,$randomClass){
	  	   
			$boxName       = __("Blog Posts", "rt_theme_admin");
			$contet_type   = "blog_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;			
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ; 
			$categories    = $isNewBox ? '' :	$options['categories'];
			$pagination    = $isNewBox ? '' :	$options['pagination']; 
			$list_orderby  = $isNewBox ? '' :	$options['list_orderby'];
			$list_order    = $isNewBox ? '' :	$options['list_order'];
			$item_per_page = $isNewBox ? '' :	$options['item_per_page']; 
			$list_layout   = isset($options["list_layout"]) ? $options["list_layout"] : "";
			$list_style    = isset($options["list_style"]) ? $options["list_style"] : "";

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';			

			$options = array (


					array(
							   "desc" => __("This module displays a bloglist following the settings below.",'rt_theme_admin'),	 
							   "hr" => "true",
							   "type" => "info", 
					),
					
					array( 
							"value"		=> "one", 						 
							"id" 		=> $theTemplateID.'_'.$theGroupID."_blog_box[layout]",
							"type" 		=> "hidden", 
					),
					
					array(  "type"		=> "table_start"),

					array(
							"name" 	=> __("Select Post Categories",'rt_theme_admin'),
							"desc" 	=> __("Select and set categories to filter (shorten) the amount of posts presented in the bloglist. If you don't select and set a category, this module will list all blogposts.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_box[categories][]",
							"options" => RTTheme::rt_get_categories(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",  
							"class"	=> $randomClass,
							"default"	=> $categories),
					
					array(
							"name"      => __("Listing Style",'rt_theme_admin'),
							"desc"      => __('Select and set one of the three available styles for listing the blog posts.','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_blog_box[list_style]", 
							"options"   => array('style1'=>'Style One  ( Big Date Boxes )','style2'=>'Style Two ( Post Type Icons )','style3'=>'Style Three ( Classic ) '),					
							"value"     => $list_style,
							"default"   => "style1",
							"dont_save" => true,
							"type"      => "select"),

					array(
							"name"      => __("Listing Layout",'rt_theme_admin'),
							"desc"      => __('Select and set the column layout for listing the blog posts. (<strong>Note</strong> : when used in a column module which is f.e. set to a 1/5 column it is better to set the blog column layout to a 1/1 layout.)','rt_theme_admin'),
							"id"        => $theTemplateID.'_'.$theGroupID."_blog_box[list_layout]", 
							"options"   => array('one'=>'One Column','two'=>'Two Columns','three'=>'Three Columns','four'=>'Four Columns','five'=>'Five Columns'),					
							"value"     => $list_layout,
							"default"   => "one",
							"dont_save" => true,
							"type"      => "select"),

					array(  "type"		=> "td_col"),

					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the blog posts within the bloglist by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_box[list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),					
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_box[list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 				
							"type" 	=> "select"),
	
					array(
							"name" 	=> __("Amount of blog post per page",'rt_theme_admin'),
							"desc"	=> __("Set the amount of posts to display at once per page.<br /><strong>Note</strong> : works in conjunction with the pagination settings.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_box[item_per_page]",
							"min"	=> "1",
							"max"	=> "200",
							"class"	=> $randomClass,
							"value"	=> $item_per_page,
							"default"	=> "9",
							"dont_save" => true, 
							"type" 	=> "rangeinput"),

					array(
							"name" 	=> __("Pagination",'rt_theme_admin'),
							"check_desc"  => __("Enable (if checked) the pagination ability for the bloglist.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_box[pagination]",
							"type" 	=> "checkbox",
							"class"	=> $randomClass,
							"value"	=> $pagination,  
							"default"	=> "off",
							"std" 	=> "false"),

					array(  "type"		=> "table_end"),	
					
					);
						
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';	
	}

	#
	#	Blog Carousel Box
	#
	function rt_generate_blog_carousel($theGroupID,$theTemplateID,$options,$randomClass){
	   
				
	   
			$boxName		= __("Blog Carousel", "rt_theme_admin");
			$contet_type	= "blog_carousel";
			$theTemplateID  = str_replace('_'.$contet_type,'',$theTemplateID);
			
			$isNewBox = (trim($randomClass)=="") ? false : true;
			
			$opacity    = 1;
			$layout        = "one passive_module" ;
			$position		= $isNewBox ? 'open minus'	:'plus';
			$data_position	= 'display: none;';  
			$categories	= isset( $options['categories'] ) ? $options['categories'] : array() ; 
			$values	= isset( $options['values'] ) ? $options['values'] : array() ; 

			$heading = $heading_icon = $list_order = $list_orderby = $item_width = $max_item = $crop = $display_excerpts = $limit_chars = "";
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';			

			$options = array (
					
					array(
							"desc" => __("This module displays blog posts as a carousel following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),


					array(	"type" => "table_start"),
					 	


					array(
							"name" => __("Heading",'rt_theme_admin'),
							"desc"      => __('Enter a title to be displayed above the blog posts carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][heading]", 
							"value"=> $heading,
							"type" => "text"
					), 

					array(
							"name" => __("Heading Icon",'rt_theme_admin'),
							"desc"      => __('Select and set a icon to precede the blog posts carousel title.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][heading_icon]", 
							"class" => "icon_selection",
							"value"=> $heading_icon,
							"type" => "text"
					), 


					array(
							"name" 	=> __("Select Categories",'rt_theme_admin'),
							"desc" 	=> __("Select and set categories to filter (shorten) the amount of blog posts presented in the carousel. If you don't select and set a category, this module will list all blogposts.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_carousel[values][categories][]",
							"options" => RTTheme::rt_get_categories(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $categories),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the blog posts within the carousel by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),		 
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 		
							"type" 	=> "select"),


					array(
							"name" => __("Custom Excerpts Size",'rt_theme_admin'),
							"desc" => __('Give a number to change the charackter size of the post excerpts.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][limit_chars]", 
							"value"=> $limit_chars,
							"type" => "text"
					), 
					
					array(	"type" => "td_col" ),	
 

					array(
							"name" 	=> __("Carousel Style",'rt_theme_admin'),
							"desc"      => __('Select and set the carousel style.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][style]",
							"options" =>	array(
										"plain_carousel" => "Plain Box", 
										"rounded_carousel" => "With Borders", 									
								),
							"default"=>"1",
							"value"=>$item_width,
							"type" => "select"), 


					array(
							"name" 	=> __("Maximum Items",'rt_theme_admin'),
							"desc"	=> __("Set the amount of blog posts to be displayed within the carousel.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_carousel[values][max_item]",
							"min"	=> "1",
							"max"	=> "200",
							"class"	=> $randomClass,
							"value"	=> $max_item,
							"default"	=> "9",
							"dont_save" => true, 
							"type" 	=> "rangeinput"),
			
					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"      => __('Select and set the column layout for the carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_blog_carousel[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"default"=>"1",
							"value"=>$item_width,  
							"hr" => "true",
							"type" => "select"), 	

					array(
							"name" 	=> __("Display Excerpts. (check to add blog excerpts to the carousel)",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_carousel[values][display_excerpts]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_excerpts, 		 
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Crop Images (check to enable cropping of the blog post featured image)",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_blog_carousel[values][crop]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $crop, 	 
							"default"	=> "on",
							"std" 	=> "false"),

					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';	
	}

	#
	#	Portfolio Box
	#
	function rt_generate_portfolio_box($theGroupID,$theTemplateID,$options,$randomClass){ 
	   
			$boxName	   = __("Portfolio Posts", "rt_theme_admin");
			$contet_type   = "portfolio_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			
			$isNewBox = (trim($randomClass)=="") ? false : true;
			
			$opacity	= 1;
			$layout		= "one passive_module";
			$position	= $isNewBox ? 'open minus':'plus';
			$data_position	= 'display: none;';		 

			$values        = isset( $options['values'] ) ? $options['values'] : array() ;  

			$pagination = $item_width = $item_per_page = $portf_list_orderby = $portf_list_order = $pagination = $filterable = $list_order = $categories = $display_descriptions = $display_embedded_titles =  $display_titles = "";
			extract( $values );		
		
			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (

					array(
							   "desc" => __("This module displays portfolio list following the settings below.",'rt_theme_admin'),	 
							   "hr" => "true",
							   "type" => "info", 
					),
				
					array( "type"	=> "table_start"),	
 
					array(
							"name" 	=> __("Select Portfolio Categories",'rt_theme_admin'),
							"desc" 	=> __("Select categories to filter (shorten) the amount of portfolio items presented in the portfolio list. If you don't select and set a category, this module will list all portfolio items.",'rt_theme_admin'),							
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][categories][]",
							"options" => RTTheme::rt_get_portfolio_categories(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $categories),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the portfolio items within the portfolio list by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_box[values][portf_list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),		 
							"value"	=> $portf_list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_box[values][portf_list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $portf_list_order,
							"default"	=> "DESC",
							"dont_save" => true, 					
							"type" 	=> "select"),
	
	

					array(
						"name" 	=> __("Amount of portfolio item per page",'rt_theme_admin'),
						"desc"	=> __("Set the amount of portfolio items to display at once per page.<br /><strong>Note</strong> : works in conjunction with the pagination settings.",'rt_theme_admin'),
						"id" => $theTemplateID.'_'.$theGroupID."_portfolio_box[values][item_per_page]",
						"min"	=> "1",
						"max"	=> "200",
						"class"	=> $randomClass,
						"value"	=> $item_per_page,
						"default"	=> "9",
						"dont_save" => true, 
						"type" 	=> "rangeinput"),
			
					array(
							   "name" 	=> __("Content Layout",'rt_theme_admin'),
							   "desc"  => __('Select and set the column layout for listing the portfolio items. (<strong>Note</strong> : when used in a column module which is f.e. set to a 1/5 column it is better to set the portfolio column layout to a 1/1 layout.)','rt_theme_admin'),
							   "id" => $theTemplateID.'_'.$theGroupID."_portfolio_box[values][item_width]",
							   "options" =>	array(
													5 => "1/5", 
													4 => "1/4",
													3 => "1/3",
													2 => "1/2",
													1 => "1/1"									
											),
							   "default"=>"3",
							   "value"=>$item_width,
							   "hr" => "true",
							   "type" => "select"),
					 
					array( "type"	=> "td_col"),
										
					array(
							"name" 	=> __("Pagination",'rt_theme_admin'),
							"desc"  => __("Enable (if checked) the pagination ability for the portfolio list.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][pagination]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $pagination,  
							"default"	=> "off",
							"std" 	=> "false"),
 

					
					array(
							"name" 	=> __("Filter Navigation",'rt_theme_admin'),
							"desc" 	=> __("Enable (if checked) toplevel filter navigation for the listed portfolio items.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][filterable]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $filterable,  
							"default"	=> "off",
							"std" 	=> "false"), 	


					array(
							"name" 	=> __("Display Titles",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][display_titles]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_titles, 		
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Display Descriptions",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][display_descriptions]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_descriptions, 		 
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Display Embedded Titles",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_box[values][display_embedded_titles]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_embedded_titles, 		 
							"default"	=> "on",
							"std" 	=> "false"),		

					array( "type"	=> "table_end"),	

					);

			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';		
	}

	#
	#	Portfolio Carousel Box
	#
	function rt_generate_portfolio_carousel($theGroupID,$theTemplateID,$options,$randomClass){
	   
			$boxName       = __("Portfolio Carousel", "rt_theme_admin");
			$contet_type   = "portfolio_carousel";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;		
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus';
			$data_position = 'display: none;' ; 
			$values        = isset( $options['values'] ) ? $options['values'] : array() ; 

			$crop = $display_descriptions = $display_titles = $item_width = $max_item = $list_order = $list_orderby = $categories = $heading_icon = $heading = "";
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					
					array(
							"desc" => __("This module displays portfolio items as a carousel following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					), 

					array(	"type" => "table_start"), 

					array(
							"name" => __("Heading",'rt_theme_admin'),
							"desc"      => __('Enter a title to be displayed above the portfolio carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][heading]", 
							"value"=> $heading,
							"type" => "text"
					), 

					array(
							"name" => __("Heading Icon",'rt_theme_admin'),
							"desc"      => __('Select and set a icon to precede the portfolio carousel title.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][heading_icon]", 
							"class" => "icon_selection",
							"value"=> $heading_icon,
							"type" => "text"
					), 


					array(
							"name" 	=> __("Select Portfolio Categories",'rt_theme_admin'),
							"desc" 	=> __("Select and set categories to filter (shorten) the amount of portfolio items presented in the carousel. If you don't select and set a category, this module will list all portfolio items.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][categories][]",
							"options" => RTTheme::rt_get_portfolio_categories(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $categories),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the portfolio items within the carsousel by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),	 
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 				
							"type" 	=> "select"),

					
					array(	"type" => "td_col" ),	

					array(
							"name" 	=> __("Carousel Style",'rt_theme_admin'),
							"desc"      => __('Select and set the carousel style.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][style]",
							"options" =>	array(
										"plain_carousel" => "Plain Box", 
										"rounded_carousel" => "With Borders",								
								),
							"default"=>"1",
							"value"=>$item_width, 
							"type" => "select"), 


					array(
							"name" 	=> __("Maximum Items",'rt_theme_admin'),
							"desc"	=> __("Set the amount of portfolio items to be displayed within the carousel.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][max_item]",
							"min"	=> "1",
							"max"	=> "200",
							"class"	=> $randomClass,
							"value"	=> $max_item,
							"default"	=> "9",
							"dont_save" => true, 
							"type" 	=> "rangeinput"),
			
					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"      => __('Select and set the column layout for the carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"default"=>"1",
							"value"=>$item_width,
							"hr" => "true",
							"type" => "select"), 	


					array(
							"name" 	=> __("Display Titles. (check to add the portfolio item title to the carousel)",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][display_titles]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_titles, 		
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Display Descriptions. (check to add the portfolio item discription to the carousel)",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][display_descriptions]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $display_descriptions, 		 
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Crop Images. (check to enable cropping the portfolio item image)",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_portfolio_carousel[values][crop]",
							"type" 	=> "checkbox2",
							"class"	=> $randomClass,
							"value"	=> $crop, 		 
							"default"	=> "on",
							"std" 	=> "false"),


					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>'; 
	}
 
	#
	#	Staff Box
	#
	function rt_generate_staff_box($theGroupID,$theTemplateID,$options,$randomClass){
	     
			$boxName		= __("Staff List", "rt_theme_admin");
			$contet_type	= "staff_box";
			$theTemplateID  = str_replace('_'.$contet_type,'',$theTemplateID);
			
			$isNewBox = (trim($randomClass)=="") ? false : true;
			
			$opacity 		= 1;
			$layout 		= "one passive_module" ;
			$position		= $isNewBox ? 'open minus'	:'plus';
			$data_position	= 'display: none;'; 
			$ids        	= isset( $options['ids'] ) ? $options['ids'] : "" ; 
			$list_orderby 	= isset( $options['list_orderby'] ) ? $options['list_orderby'] : "" ; 
			$list_order 	= isset( $options['list_order'] ) ? $options['list_order'] : "" ; 
			$style 			= isset( $options['style'] ) ? $options['style'] : "" ; 
			$item_width 	= isset( $options['item_width'] ) ? $options['item_width'] : "" ; 
			
			$values	= isset( $options['values'] ) ? $options['values'] : array() ; 
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					
					array(
							"desc" => __("This module displays a team / staff memberlist from the team / staff post type following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),

					array(	"type" => "table_start"),

					array(
							"name" 	=> __("Select Staff (Optional)",'rt_theme_admin'),
							"desc" 	=> __("You can filter team / staff members by selecting them from this list. If you don't select individual members, all team / staff members will be listed.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_staff_box[values][ids][]",
							"options" => RTTheme::rt_get_staff_list(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"=> $ids),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the team / staff member items within the memberlist by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_staff_box[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'), 
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_staff_box[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 					
							"type" 	=> "select"),

					
					array(	"type" => "td_col" ),	
 

					array(
							"name" 	=> __("List Style",'rt_theme_admin'),
							"desc"  => __('Select and set a style to display the team / staff memberlist.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_staff_box[values][style]",
							"options" =>	array(
										"style-one" => "Style One", 
										"style-two" => "Style Two", 									
										"style-three" => "Style Three", 									
								),
							"default"=>"style-one",
							"value"=>$style, 
							"type" => "select"), 
			
					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"  => __('Select and set the column layout for the team / staff memberlist.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_staff_box[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"default"=>"1",
							"value"=>$item_width, 
							"type" => "select"), 


					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';				
	}

	#
	#	Testimonial Box
	#
	function rt_generate_testimonial_box($theGroupID,$theTemplateID,$options,$randomClass){
	   	   
			$boxName       = __("Testimonials", "rt_theme_admin");
			$contet_type   = "testimonial_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus'	:'plus';
			$data_position = 'display: none;'; 

			$ids= $list_order = $item_width = $list_orderby = $style = ""; 
			$values	= isset( $options['values'] ) ? $options['values'] : array() ; 
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					
					array(
							"desc" => __("This module displays the testimonials created with the testimonials post type following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),


					array(	"type" => "table_start"),
					 	
 

					array(
							"name" 	=> __("Select Testimonials (Optional)",'rt_theme_admin'),
							"desc" 	=> __("You can filter testimonial items by selecting them from this list. If you don't select individual testimonials, this module will show all testimonials.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_testimonial_box[values][ids][]",
							"options" => RTTheme::rt_get_testimonial_list(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $ids
							),
					

					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"  => __('Select and set the content layout for the testimonials.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_box[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"default"=>"1",
							"value"=>$item_width, 
							"type" => "select"), 

					array(
							"name" 	=> __("Style",'rt_theme_admin'), 
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_box[values][style]",
							"options" =>	array(
										"centered" => "Big Text / Center Aligned", 
										"" => "Small Text / Left Aligned",
								),
							"value"=>$style, 
							"type" => "select"), 

					array(	"type" => "td_col" ),	 
		
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the testimonial items within the list by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_box[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_box[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 
							"type" 	=> "select"),

					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';			
	}

	#
	#	Testimonial Carousel
	#
	function rt_generate_testimonial_carousel($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Testimonial Carousel", "rt_theme_admin");
			$contet_type   = "testimonial_carousel";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus':'plus';
			$data_position = 'display: none;'; 
			$ids           = "";
			$values        = isset( $options['values'] ) ? $options['values'] : array() ; 

			$heading = $heading_icon = $list_orderby = $list_order = $item_width = $style = "";
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';


			$options = array (
					
					array(
							"desc" => __("This module displays the testimonials created by the testimonial post type within a carousel.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),


					array(	"type" => "table_start"),
					 	


					array(
							"name" => __("Heading",'rt_theme_admin'),
							"desc" => __('Enter a title to be displayed above the testimonials carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][heading]", 
							"value"=> $heading,
							"type" => "text"
					), 

					array(
							"name" => __("Heading Icon",'rt_theme_admin'),
							"desc" => __('Select and set a icon to precede the testimonials carousel title.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][heading_icon]", 
							"class" => "icon_selection",
							"value"=> $heading_icon,
							"type" => "text"
					), 
 

					array(
							"name" 	=> __("Select Testimonials (Optional)",'rt_theme_admin'),
							"desc" 	=> __("You can filter testimonials by selecting them from this list. If you don't select one, all testimonials will be displayed.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][ids][]",
							"options" => RTTheme::rt_get_testimonial_list(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $ids ),

					array(
							"name" 	=> __("Style",'rt_theme_admin'), 
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][style]",
							"options" =>	array(
										"centered" => "Big Text / Center Aligned", 
										"" => "Small Text / Left Aligned",
								),
							"value"=>$style, 
							"type" => "select"), 


					array(	"type" => "td_col" ),	 					

					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the testimonial items within the carousel by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 				
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"  => __('Select and set the column layout for the carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_testimonial_carousel[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"value"=>$isNewBox ? 4 : $item_width, 
							"type" => "select"), 		

					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';			
	}

	#
	#	Product Box
	#
	function rt_generate_product_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Product Posts", "rt_theme_admin");
			$contet_type   = "product_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus':'plus'; 
			$data_position = 'display: none;'	; 

			$values        = isset( $options['values'] ) ? $options['values'] : array() ;  

			$heading = $pagination = $item_width = $list_orderby = $list_orderby = $list_order = $item_per_page = $categories = $display_descriptions = $display_price =  $display_titles = $with_borders = $with_effect = $no_top_border = $no_bottom_border = "";
			extract( $values );					


			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					
						array(
								"desc" => __("This module displays product items following the settings below.",'rt_theme_admin'),	 
								"hr" => "true",
								"type" => "info", 
						), 

						array(	"type" => "table_start"),
						 	

						array(
								"name" => __("Embedded Heading",'rt_theme_admin'),
								"desc"      => __('Enter a title to be displayed as embedded to the grid.','rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_product_box[values][heading]", 
								"value"=> $heading,
								"type" => "text"
						), 

						array(
								"name" 	=> __("Select Product Categories",'rt_theme_admin'),
								"desc" 	=> __("Select and set categories to filter (shorten) the amount of product items presented in the productlist. If you don't select and set a category, this module will list all product items.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][categories][]",
								"options" => RTTheme::rt_get_product_categories(),
								"purpose" => "sidebar",
								"type"	=> "selectmultiple",
								"class"	=> $randomClass,
								"default"	=> $categories),
						
						array(
								"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
								"desc" 	=> __("Select and set the sorting order for the product items within the product list by this parameter.",'rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_product_box[values][list_orderby]", 
								"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),	 
								"value"	=> $list_orderby,
								"default"	=> "date",
								"dont_save" => true,
								"type" 	=> "select"),
				
						array(
								"name" 	=> __("Order",'rt_theme_admin'),
								"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_product_box[values][list_order]", 
								"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
								"value"	=> $list_order,
								"default"	=> "DESC",
								"dont_save" => true, 			
								"type" 	=> "select"),						

						array(
								"name" 	=> __("Amount of product post per page",'rt_theme_admin'),
								"desc"	=> __("Set the amount of product items to display at once per page.<br /><strong>Note</strong> : works in conjunction with the pagination settings.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][item_per_page]",
								"min"	=> "1",
								"max"	=> "200",
								"class"	=> $randomClass,
								"value"	=> $item_per_page,
								"default"	=> "9",
								"dont_save" => true, 
								"type" 	=> "rangeinput"),
				
						array(
								"name" 	=> __("Content Layout",'rt_theme_admin'),
								"desc"  => __('Select and set the column layout for listing the product items. (<strong>Note</strong> : when used in a column module which is f.e. set to a 1/5 column it is better to set the content layout to a 1/1 layout.)','rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_product_box[values][item_width]",
								"options" =>	array(
											5 => "1/5", 
											4 => "1/4",
											3 => "1/3",
											2 => "1/2",
											1 => "1/1"									
									),
								"default"=>"1",
								"value"=>$item_width, 
								"type" => "select"), 

						array(	"type" => "td_col" ),	

						array(
								"name" 	=> __("Pagination",'rt_theme_admin'),
								"desc"  => __("Enable (if checked) the pagination ability for the product items.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][pagination]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $pagination, 	 
								"default"	=> "off",
								"std" 	=> "false"),	

						array(
								"name" 	=> __("Display Titles",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][display_titles]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $display_titles, 		
								"default"	=> "on",
								"std" 	=> "false"),

						array(
								"name" 	=> __("Display Descriptions",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][display_descriptions]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $display_descriptions, 		 
								"default"	=> "on",
								"std" 	=> "false"),

						array(
								"name" 	=> __("Display Prices",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][display_price]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $display_price, 		 
								"default"	=> "on",
								"std" 	=> "false"),					


						array(
								"name" 	=> __("Display as Grid",'rt_theme_admin'),
								"desc"  => __("Enable (if checked) the list will be displayed in grid style.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][with_borders]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $with_borders, 	  
								"std" 	=> "false"),	

						array(
								"name" 	=> __("Enable Sliding Info",'rt_theme_admin'),
								"desc"  => __("Enable (if checked) the mouse over sliding info for the items.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][with_effect]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $with_effect, 	 
								"default"	=> "off",
								"std" 	=> "false"),	

						array(
								"name" 	=> __("Remove Top Borders of the Grid",'rt_theme_admin'),
								"desc"  => __("Enable (if checked) to remove the top borders of the grid will be removed. In some cases you may need this option checked to make your design much beatuiful.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][no_top_border]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $no_top_border, 	  
								"std" 	=> "false"),	

						array(
								"name" 	=> __("Remove Bottom Borders of the Grid",'rt_theme_admin'),
								"desc"  => __("Enable (if checked) to remove the bottom borders of the grid will be removed. In some cases you may need this option checked to make your design much beatuiful.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_product_box[values][no_bottom_border]",
								"type" 	=> "checkbox2",
								"class"	=> $randomClass,
								"value"	=> $no_bottom_border, 	  
								"std" 	=> "false"),	




						array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>'; 
	}

	#
	#	Product Carousel Box
	#
	function rt_generate_product_carousel($theGroupID,$theTemplateID,$options,$randomClass){
	   	   
			$boxName       = __("Product Carousel", "rt_theme_admin");
			$contet_type   = "product_carousel";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus';
			$data_position = 'display: none;' ; 			
			$values        = isset( $options['values'] ) ? $options['values'] : array() ;  

			$item_width = $max_item = $crop = $list_order = $list_orderby = $categories = $heading_icon  = $heading = "" ;
			extract( $values );

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';


			$options = array (
					
					array(
							"desc" => __("This module displays product items as a carousel following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),

					array(	"type" => "table_start"),
					 	

					array(
							"name" => __("Heading",'rt_theme_admin'),
							"desc"      => __('Enter a title to be displayed above the product carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][heading]", 
							"value"=> $heading,
							"type" => "text"
					), 

					array(
							"name" => __("Heading Icon",'rt_theme_admin'),
							"desc"      => __('Select and set a icon to precede the product carousel title.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][heading_icon]", 
							"class" => "icon_selection",
							"value"=> $heading_icon,
							"type" => "text"
					), 

					array(
							"name" 	=> __("Select Product Categories",'rt_theme_admin'),
							"desc" 	=> __("Select and set categories to filter (shorten) the amount of product items presented in the carousel. If you don't select and set a category, this module will show all product items.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_product_carousel[values][categories][]",
							"options" => RTTheme::rt_get_product_categories(),
							"purpose" => "sidebar",
							"type"	=> "selectmultiple",
							"class"	=> $randomClass,
							"default"	=> $categories),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the product items within the product carousel by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),		 
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 				
							"type" 	=> "select"),

					
					array(	"type" => "td_col" ),	

					array(
							"name" 	=> __("Crop Image",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_product_carousel[values][crop]",
							"check_desc" 	=> __("Enable (if checked) cropping for product images",'rt_theme_admin'),
							"type" 	=> "checkbox",
							"class"	=> $randomClass,
							"value"	=> $crop,
							"default"	=> "on",
							"std" 	=> "false"),

					array(
							"name" 	=> __("Carousel Style",'rt_theme_admin'),
							"desc"      => __('Select and set the carousel style.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][style]",
							"options" =>	array(
										"plain_carousel" => "Plain Box", 
										"rounded_carousel" => "With Borders",									
								),
							"default"=>"1",
							"value"=>$item_width, 
							"type" => "select"), 


					array(
							"name" 	=> __("Maximum product",'rt_theme_admin'),
							"desc"	=> __("Set the amount of product items to be displayed within the carousel.",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_product_carousel[values][max_item]",
							"min"	=> "1",
							"max"	=> "200",
							"class"	=> $randomClass,
							"value"	=> $max_item,
							"default"	=> "9",
							"dont_save" => true, 
							"type" 	=> "rangeinput"),
			
					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"      => __('Select and set the column layout for the carousel.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_product_carousel[values][item_width]",
							"options" =>	array(
										5 => "1/5", 
										4 => "1/4",
										3 => "1/3",
										2 => "1/2",
										1 => "1/1"									
								),
							"default"=>"1",
							"value"=>$item_width, 
							"type" => "select"), 
		

					array(	"type" => "table_end" ),						
					
					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	WooCommerce Box
	#	
	function rt_generate_woo_products_box($theGroupID,$theTemplateID,$options,$randomClass){
	   
			$boxName       = __("WooCommerce Products", "rt_theme_admin");
			$contet_type   = "woo_products_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;			
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus'	;
			$data_position = 'display: none;' ; 
			$item_width    = $isNewBox ? '' : $options['item_width'] ; 
			$pagination    = isset( $options['pagination'] ) ? $options['pagination'] : ""; 			
			$categories    = isset( $options['categories'] ) ? $options['categories'] : ""; 
			$list_orderby  = $isNewBox ? '' : $options['list_orderby'];
			$list_order    = $isNewBox ? '' : $options['list_order'];
			$item_per_page = $isNewBox ? '' : $options['item_per_page']; 
		
			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					
					array(
							   "desc" => __("This module displays WooCommerce products following the settings below.",'rt_theme_admin'),	 
							   "hr" => "true",
							   "type" => "info", 
					),
					
					array(	"type" => "table_start" ),		
 

					array(
							"name" 	=> __("Select a WooCommerce Product Category",'rt_theme_admin'),
							"desc" 	=> __("You need to select a woocommerce product category from the list below. ",'rt_theme_admin'),
							"id" 	=> $theTemplateID.'_'.$theGroupID."_woo_products_box[categories]",
							"options" => RTTheme::rt_get_woo_product_categories(),
							"purpose" => "sidebar",
							"type"	=> "select",
							"class"	=> $randomClass,
							"default"	=> $categories,							
							"value"	=>$categories,),
					
					array(
							"name" 	=> __("OrderBy Parameter",'rt_theme_admin'),
							"desc" 	=> __("Select and set the sorting order for the woocommerce products within the product list by this parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_woo_products_box[list_orderby]", 
							"options" => array('author'=>'Author','date'=>'Date','title'=>'Title','modified'=>'Modified','ID'=>'ID','rand'=>'Randomized'),					
							"value"	=> $list_orderby,
							"default"	=> "date",
							"dont_save" => true,
							"type" 	=> "select"),
			
					array(
							"name" 	=> __("Order",'rt_theme_admin'),
							"desc" 	=> __("Select and set the ascending or descending order for the ORDERBY parameter.",'rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_woo_products_box[list_order]", 
							"options" => array('ASC'=>'Ascending','DESC'=>'Descending'),
							"value"	=> $list_order,
							"default"	=> "DESC",
							"dont_save" => true, 				
							"type" 	=> "select"),
					
					array(	"type" => "td_col" ),	

					array(
						"name" 	=> __("Amount of products",'rt_theme_admin'),
						"desc"	=> __("Set the amount of products to be displayed within this module box.",'rt_theme_admin'),
						"id" 	=> $theTemplateID.'_'.$theGroupID."_woo_products_box[item_per_page]",
						"min"	=> "1",
						"max"	=> "200",
						"class"	=> $randomClass,
						"value"	=> $item_per_page,
						"default"	=> "9",
						"dont_save" => true, 
						"type" 	=> "rangeinput"),
			
					array(
						"name" 	=> __("Content Layout",'rt_theme_admin'),
						"desc"  => __('Select and set the column layout for the listed products.','rt_theme_admin'),
						"id" => $theTemplateID.'_'.$theGroupID."_woo_products_box[item_width]",
						"options" =>	array(
											5 => "1/5", 
											4 => "1/4",
											3 => "1/3",
											2 => "1/2",
											1 => "1/1"									
									),
						"default"=>"1",
						"value"=>$item_width, 
						"type" => "select"), 
									
	
					array(	"type" => "table_end" ),	

					);
						
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';		
	}

	#
	#	Slider Box
	#
	function rt_generate_sidebar_box($theGroupID,$theTemplateID,$options,$randomClass){
		global $rt_sidebars_class; 

			$boxName          = __("Sidebar", "rt_theme_admin");
			$contet_type      = "sidebar_box";
			$theTemplateID    = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox         = (trim($randomClass)=="") ? false : true;			
			$opacity          = 1;
			$layout           = "one passive_module" ;	
			$position         = $isNewBox ? 'open minus' : 'plus' ;
			$data_position    = 'display: none;' ;
			$sidebar_id       = $isNewBox ? '' : $options['sidebar_id'] ;
			$widget_box_width = $isNewBox ? '' : $options['widget_box_width']	; 
			
			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (

						array(
							"desc" => __("This module displays a sidebar (widget area) following the settings below.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
						), 

						array(
								"name" => __("Select Sidebar (Widget Area)",'rt_theme_admin'),
								"desc" => __("Select and set a sidebar you want to display within this module.",'rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_sidebar_box[sidebar_id]",
								"options" => $rt_sidebars_class->rt_active_sidebars,
								"class"=>$randomClass,
								"value"=>$sidebar_id, 
								"hr" => "true",
								"type" => "select", 
						),

						array(
								"name" => __("Select Widgets Size",'rt_theme_admin'),
								"desc" => __("Select a column layout to display the widgets from this sidebar.",'rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_sidebar_box[widget_box_width]",
								"options" =>	array(
													5 => "1/5", 
													4 => "1/4",
													3 => "1/3",
													2 => "1/2",
													1 => "1/1"									
											),
								"default"=>"1",
								"value"=>$widget_box_width,
								"hr" => "true",
								"type" => "select"
						), 	 
					); 

			echo  $this->rt_generate_forms($options); 
			echo  '</div></div></div></li>'; 
	}

	#
	#	Google Map Box
	#
	function rt_generate_google_map($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Google Map", "rt_theme_admin");
			$contet_type   = "google_map";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module";
			$position      = $isNewBox ? 'open minus' : 'plus';
			$data_position = 'display: none;'; 
			$module_title  = isset($options["module_title"]) ? $options["module_title"] : ""; 
			$height        = isset($options["height"]) ? $options["height"] : ""; 
			$zoom          = isset($options["zoom"]) ? $options["zoom"] : ""; 
			$list          = isset($options["list"]) ? $options["list"] : ""; 
		
			echo '<li class="ui-state-default '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (

						array(
								"desc" => __("Use this module to insert a google map that displays a single or multiple locations (address markers).<br /><br />Use the &#39;add new location&#39; button to add one or more locations (address markers) to the map.<br /><strong>Note</strong> : per location add the latitude, longitude values, a title and a description (for the description field simple formatting with h & br tags is allowed).<br /><strong>Note</strong> : If more then one location is entered the zoom level is ignored and the map is centered between the locations.",'rt_theme_admin'),	 
								"hr" => "true",
								"type" => "info", 
						),  

						array( 
								"type" => "col_start",
								"layout" => "three",
								"holder_class" => "labels_block box_border paddings",
						),

						array(
								"name" => __("Module Title",'rt_theme_admin'),
								"desc"      => __('Enter a title to be displayed above the map.','rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_google_map[module_title]", 
								"value"=> $module_title,
								"type" => "text"
						),  

						array(
								"name" 		=> __("Height of the map",'rt_theme_admin'),
								"desc"      => __('Set the height of the map.','rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_google_map[height]",  
								"min"		=>"1",
								"max"		=>"800",
								"default"   =>"300", 
								"dont_save"	=> true,
								"value"		=> $height,  
								"class"		=> $randomClass,
								"type"		=> "rangeinput"
						), 

						array(
								"name" 		=> __("Zoom Level",'rt_theme_admin'),
								"desc"      => __('Set the zoom level of the map. <strong>Note</strong> : Does not work with more then one location added.','rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_google_map[zoom]",  
								"min"		=>"3",
								"max"		=>"21",
								"default"   =>"6", 
								"dont_save"	=> true,
								"value"		=> $zoom,  
								"class"		=> $randomClass,
								"type"		=> "rangeinput"
						), 



						array( 
								"type" => "col_split",
								"layout" => "two-three",
						),
 			
				);



			array_push($options, array( 
				"id" => $theTemplateID.'_'.$theGroupID."_google_map_holder",
				"div_class" => "google_map_holder", 
				"type" => "div_start", 
			)); 

			array_push($options, array( 
				"id" => $theTemplateID.'_'.$theGroupID."_google_map",
				"ul_class" => "google_map_list", 
				"type" => "ul_start", 
			)); 
										
			if( is_array( $list ) ){
				foreach ( $list["geo"] as $key => $value ) {
						
					$geo  = ! empty( $list["geo"][$key] ) ? $list["geo"][$key] : "";	
					$title  = ! empty( $list["title"][$key] ) ? $list["title"][$key] : "";	
					$text  = ! empty( $list["text"][$key] ) ? $list["text"][$key] : "";	

					if( !empty( $geo ) ){
						array_push($options, array(
							"geo_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][geo][]", 
							"title_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][title][]", 
							"text_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][text][]", 
							"geo_value"=> $geo,
							"title_value"=> $title,
							"text_value"=> $text,
							"class_name"=> "",
							"type" => "map_location")
						);
					}

				}
			}

			array_push($options, array(
				"geo_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][geo][]", 
				"title_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][title][]", 
				"text_id" => $theTemplateID.'_'.$theGroupID."_google_map[list][text][]", 
				"geo_value"=> "",
				"title_value"=> "",
				"text_value"=> "",
				"class_name"=> "hidden_line",
				"type" => "map_location")
			);

			array_push($options, array( 
				"type" => "ul_end", 
			));

			array_push($options, array(
				"add_new" => true,					
				"type" => "map_location")
			);

			array_push($options, array( 
				"type" => "div_end", 
			));				 

			echo  $this->rt_generate_forms($options);

			array_push($options, array( 
				"type" => "col_end", 
			));		

			echo  '</div></div></div></li>';
	}

	#
	#	Contact Form Box
	#
	function rt_generate_contact_form($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("Contact Form", "rt_theme_admin");
			$contet_type   = "contact_form";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);			
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus';
			$data_position = 'display: none;';
			$text          = isset( $options['text'] ) ? $options['text'] : '' ;  			

			echo '<li class="ui-state-default '.$layout.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
						array(
							"desc" => __("You can use this template module to add a contactform to the page content.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
						),
						 
						array("type" 	=> "table_start"),					

						array(
								"name" => __("Contactform Title",'rt_theme_admin'),
								"desc"      => __('Enter a title to be displayed above the contactform.','rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_contact_form[title]",
								"value"=>@$options["title"], 
								"type" => "text"),

						array(
								"name" 		=> __("Description",'rt_theme_admin'),
								"desc"      => __('Enter a (short) description. Any valid html and shortcode are allowed.','rt_theme_admin'),
								"id" 		=> $theTemplateID.'_'.$theGroupID."_contact_form[text]",
								"value"		=> $text, 
								"type" 		=> "textarea" 
						),							
			
						array(
								"name" 	=> __("Contact Form Email",'rt_theme_admin'),
								"desc" 	=> __("The contactform will send the email to the emailaddress as set in this field.",'rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_contact_form[email]",
								"default"	=> get_option('admin_email'),
								"dont_save"=> true,
								"value"	=>@$options["email"], 
								"type" 	=> "text"),

						array("type" 	=> "td_col"),	 
			
						array(
								"name" 	=> __("3rd party contactform shortcode",'rt_theme_admin'),
								"desc" 	=> __('Insert in here any 3rd party contactform shortcode to replace the theme default contactform. There are great contactform plugins on the <a href="http://wordpress.org/extend/plugins/">WordPress plugins page</a> like <a href="http://wordpress.org/extend/plugins/contact-form-7/">Contact Form 7</a>.','rt_theme_admin'),
								"id" 	=> $theTemplateID.'_'.$theGroupID."_contact_form[shortcode]",
								"value"	=>@$options["shortcode"], 
								"hr" => "true",
								"type" 	=> "textarea"),	 

						array("type" 	=> "table_end"),	 
					);
					
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Icon List Box
	#
	function rt_generate_icon_list_box($theGroupID,$theTemplateID,$options,$randomClass){

			$boxName       = __("List With Icons", "rt_theme_admin");
			$contet_type   = "icon_list_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID);
			$isNewBox      = (trim($randomClass)=="") ? false : true;
			$opacity       = 1;
			$layout        = "one passive_module";
			$position      = $isNewBox ? 'open minus' : 'plus';
			$data_position = 'display: none;';
			$module_title  = isset( $options['module_title'] ) ? $options['module_title'] : '' ;  			
			$list          = isset( $options['list'] ) ? $options['list'] : '' ;  		
			$icon_style    = isset( $options['icon_style'] ) ? $options['icon_style'] : '' ;  
			$item_width    = isset( $options['item_width'] ) ? $options['item_width'] : '' ;   

			echo '<li class="ui-state-default '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
					array(
							"desc" => __("You can use this module to add a detailed information list preceded with icons (f.e. contact information). <br /><strong>Note</strong> : Add a icon and line of text per listed item.",'rt_theme_admin'),	 
							"hr" => "true",
							"type" => "info", 
					),  

					array( 
							"type" => "col_start",
							"layout" => "three",
							"holder_class" => "labels_block box_border paddings",							
					),

					array(
							"name" => __("List Title",'rt_theme_admin'),
							"desc"      => __('Enter the title to be displayed above the detailed list.','rt_theme_admin'),							
							"id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[module_title]",
							"hr" => "true",
							"value"=> $module_title,
							"type" => "text"
					), 

					array( 
							"type" => "col_split",
							"layout" => "three"
					),

					array(
							"name" 	=> __("Content Layout",'rt_theme_admin'),
							"desc"  => __('Select and set the column layout for listing the list items.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[item_width]",
							"options" => array(
											1 => "1/1",
											2 => "1/2",	
											3 => "1/3",
											4 => "1/4",	
											5 => "1/5" 
										),
							"default"=>"1", 
							"hr" => "true", 
							"value"=>$item_width, 
							"type" => "select"), 

					array( 
							"type" => "col_split",
							"layout" => "three"
					), 

					array(
							"name"      => __("Icon Style",'rt_theme_admin'),
							"desc"      => __('Select and set the default icon color for each of the listed items.','rt_theme_admin'),
							"id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[icon_style]",
							"options"   =>  array(
								"default" => "Content Color", 
								"colored" => "Primary Color",
								"light" => "Light Grey",
								"default big_icons" => "Big Icons - Content Color", 
								"colored big_icons" => "Big Icons - Primary Color",
								"light big_icons" => "Big Icons - Light Grey",
								"default big_icons icon_borders" => "Big Icons - Content Color w/ Borders", 
								"colored big_icons icon_borders" => "Big Icons - Primary Color w/ Borders",
								"light big_icons icon_borders" => "Big Icons - Light Grey w/ Borders",
								),
							"value"		=> $icon_style,
							"hr"		=> "true",
							"type"      => "select", 
					),	 


					array( 
							"type" => "col_end"
					),
			); 

			array_push($options, array( 
				"id" => $theTemplateID.'_'.$theGroupID."_icon_list_holder",
				"div_class" => "icon_list_holder", 
				"type" => "div_start", 
			)); 

			array_push($options, array( 
				"id" => $theTemplateID.'_'.$theGroupID."_icon_list",
				"ul_class" => "icon_list", 
				"type" => "ul_start", 
			)); 
										
			if( is_array( $list ) ){
				foreach ( $list["text"] as $key => $value ) {
						
					$list_text  = ! empty( $list["text"][$key] ) ? $list["text"][$key] : "";	
					$list_icon  = ! empty( $list["icon"][$key] ) ? $list["icon"][$key] : "";	

					if( !empty( $list_text ) ){
						array_push($options, array(
							"icon_id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[list][icon][]", 
							"text_id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[list][text][]", 
							"icon_value"=> $list_icon,
							"text_value"=> $list_text,
							"class_name"=> "",
							"type" => "icon_list")
						);
					}

				}
			}

			array_push($options, array(
				"icon_id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[list][icon][]", 
				"text_id" => $theTemplateID.'_'.$theGroupID."_icon_list_box[list][text][]", 
				"icon_value"=> "",
				"text_value"=> "",
				"class_name"=> "hidden_line",
				"type" => "icon_list")
			);

			array_push($options, array( 
				"type" => "ul_end", 
			));

			array_push($options, array(
				"add_new" => true,					
				"type" => "icon_list")
			);

			array_push($options, array( 
				"type" => "div_end", 
			));				 

			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}

	#
	#	Code Box
	#
	function rt_generate_code_box($theGroupID,$theTemplateID,$options,$randomClass){ 

			$boxName       = __("Code Box", "rt_theme_admin");
			$contet_type   = "code_box";
			$theTemplateID = str_replace('_'.$contet_type,'',$theTemplateID); 
			$isNewBox      = (trim($randomClass)=="") ? false : true; 
			$opacity       = 1;
			$layout        = "one passive_module" ;
			$position      = $isNewBox ? 'open minus' : 'plus' ;
			$data_position = 'display: none;' ; 
			$code_space    = isset( $options["code_space"] ) ? $options["code_space"] : "" ;
			$heading       = isset( $options["heading"] ) ? $options["heading"] : "" ;
		
			echo '<li class="ui-state-default '.$layout.' '.$randomClass.'" style="opacity:'.$opacity.';">';
			echo '<div class="box_shadow"><div class="Itemholder"><div class="Itemheader"><h5>'.$boxName.'</h5>';
			echo $this->module_controls( $isNewBox );
			echo '</div><div class="ItemData" style="'.$data_position.'">';
			echo '<input type="hidden" name="theTemplateID_'.$theGroupID.'" value="'.$theTemplateID.'"><input type="hidden" name="theGroupID_'.$theGroupID.'" value="'.$theGroupID.'"><input type="hidden" name="source_type_'.$theGroupID.'" value="'.$contet_type.'">';

			$options = array (
	 
						array(
								"desc" => __("Use this module to add your shortcodes, valid HTML-code, javascript or unformatted text at the location of the codebox within the template to the page.",'rt_theme_admin'),	 
								"hr" => "true",
								"type" => "info"), 
 
						array(
								"name" => __("Module Title",'rt_theme_admin'),
								"desc"      => __('Enter any title for the codebox (optional).','rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_code_box[heading]",
								"value"=>$heading,
								"type" => "text"), 

						array(
								"name" => __("Code Space",'rt_theme_admin'),
								"desc" => __("Enter / paste your shortcode, javascript or valid HTML-code.",'rt_theme_admin'),
								"id" => $theTemplateID.'_'.$theGroupID."_code_box[code_space]",
								"value"=>$code_space,
								"type" => "textarea"),  
 
					);
										
			
			echo  $this->rt_generate_forms($options);
			
			echo  '</div></div></div></li>';
	}		
}


$RTThemePageLayoutOptionsClass = new RTThemePageLayoutOptions(); 
?>